@@ -55,8 +55,11 @@
 */
 FEditCanvas::FEditCanvas( MainWindow * parent )
     : QWidget( parent, 0, Qt::WNoAutoErase )
-    , M_scale( 1.0 )
-    , M_center( 0, 0 )
+    , M_field_scale( 1.0 )
+    , M_zoomed( false )
+    , M_field_center( 0, 0 )
+    , M_focus_point( 0.0, 0.0 )
+    , M_enlarged( true )
     , M_field_brush( QColor( 31, 160, 31 ), Qt::SolidPattern )
     , M_field_dark_brush( QColor( 15, 143, 15 ), Qt::SolidPattern )
     , M_line_pen( QColor( 255, 255, 255 ), 1, Qt::SolidLine )
@@ -100,21 +103,24 @@ FEditCanvas::~FEditCanvas()
 void
 FEditCanvas::updateSize()
 {
-    M_center.setX( this->width() / 2 );
-    M_center.setY( this->height() / 2 );
+    M_field_center.setX( this->width() / 2 - scale( focusPoint().x ) );
+    M_field_center.setY( this->height() / 2 - scale( focusPoint().y ) );
 
     const double pitch_l = ( FEditConfig::PITCH_LENGTH
                              + FEditConfig::PITCH_MARGIN * 2.0 );
     const double pitch_w = ( FEditConfig::PITCH_WIDTH
                              + FEditConfig::PITCH_MARGIN * 2.0 );
 
-    M_scale = this->width() / pitch_l;
-    if ( pitch_w * M_scale > this->height() )
+    if ( ! M_zoomed )
     {
-        M_scale = this->height() / pitch_w;
-    }
+        M_field_scale = this->width() / pitch_l;
+        if ( pitch_w * M_field_scale > this->height() )
+        {
+            M_field_scale = this->height() / pitch_w;
+        }
 
-    M_scale = std::max( 2.0, M_scale );
+        M_field_scale = std::max( 2.0, M_field_scale );
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -162,10 +168,10 @@ FEditCanvas::drawField( QPainter & painter )
     drawContainedArea( painter );
 
     // set screen coordinates of field
-    const int left_x   = getScreenX( - FEditConfig::PITCH_LENGTH * 0.5 );
-    const int right_x  = getScreenX( + FEditConfig::PITCH_LENGTH * 0.5 );
-    const int top_y    = getScreenY( - FEditConfig::PITCH_WIDTH * 0.5 );
-    const int bottom_y = getScreenY( + FEditConfig::PITCH_WIDTH * 0.5 );
+    const int left_x   = screenX( - FEditConfig::PITCH_LENGTH * 0.5 );
+    const int right_x  = screenX( + FEditConfig::PITCH_LENGTH * 0.5 );
+    const int top_y    = screenY( - FEditConfig::PITCH_WIDTH * 0.5 );
+    const int bottom_y = screenY( + FEditConfig::PITCH_WIDTH * 0.5 );
 
     //--------------------------------------
     // draw lines
@@ -178,40 +184,40 @@ FEditCanvas::drawField( QPainter & painter )
     painter.drawLine( right_x, bottom_y, left_x, bottom_y );
     painter.drawLine( left_x, bottom_y, left_x, top_y );
     // center line
-    painter.drawLine( M_center.x(), top_y, M_center.x(), bottom_y );
+    painter.drawLine( M_field_center.x(), top_y, M_field_center.x(), bottom_y );
     // center circle
     const int center_radius = scale( FEditConfig::CENTER_CIRCLE_R );
-    painter.drawEllipse( M_center.x() - center_radius,
-                         M_center.y() - center_radius,
+    painter.drawEllipse( M_field_center.x() - center_radius,
+                         M_field_center.y() - center_radius,
                          center_radius * 2,
                          center_radius * 2 );
     // draw penalty area box
-    const int pen_top_y    = getScreenY( - FEditConfig::PENALTY_AREA_WIDTH / 2 );
-    const int pen_bottom_y = getScreenY( + FEditConfig::PENALTY_AREA_WIDTH / 2 );
+    const int pen_top_y    = screenY( - FEditConfig::PENALTY_AREA_WIDTH / 2 );
+    const int pen_bottom_y = screenY( + FEditConfig::PENALTY_AREA_WIDTH / 2 );
     // left penalty box
-    int pen_x = getScreenX( -( FEditConfig::PITCH_LENGTH*0.5
-                                - FEditConfig::PENALTY_AREA_LENGTH ) );
+    int pen_x = screenX( -( FEditConfig::PITCH_LENGTH*0.5
+                            - FEditConfig::PENALTY_AREA_LENGTH ) );
     painter.drawLine( left_x, pen_top_y, pen_x, pen_top_y );
     painter.drawLine( pen_x, pen_top_y, pen_x, pen_bottom_y );
     painter.drawLine( pen_x, pen_bottom_y, left_x, pen_bottom_y );
     // right penalty box
-    pen_x = getScreenX( +( FEditConfig::PITCH_LENGTH*0.5
+    pen_x = screenX( +( FEditConfig::PITCH_LENGTH*0.5
                         - FEditConfig::PENALTY_AREA_LENGTH ) );
     painter.drawLine( right_x, pen_top_y, pen_x, pen_top_y );
     painter.drawLine( pen_x, pen_top_y, pen_x, pen_bottom_y );
     painter.drawLine( pen_x, pen_bottom_y, right_x, pen_bottom_y );
     // draw goal area box
     const int goal_area_y_abs = scale( FEditConfig::GOAL_AREA_WIDTH*0.5 );
-    const int goal_area_top_y = M_center.y() - goal_area_y_abs;
-    const int goal_area_bottom_y = M_center.y() + goal_area_y_abs;
+    const int goal_area_top_y = M_field_center.y() - goal_area_y_abs;
+    const int goal_area_bottom_y = M_field_center.y() + goal_area_y_abs;
     // left goal area
-    int goal_area_x = getScreenX( - FEditConfig::PITCH_LENGTH*0.5
+    int goal_area_x = screenX( - FEditConfig::PITCH_LENGTH*0.5
                                + FEditConfig::GOAL_AREA_LENGTH );
     painter.drawLine( left_x, goal_area_top_y, goal_area_x, goal_area_top_y );
     painter.drawLine( goal_area_x, goal_area_top_y, goal_area_x, goal_area_bottom_y );
     painter.drawLine( goal_area_x, goal_area_bottom_y, left_x, goal_area_bottom_y );
     // right goal area
-    goal_area_x = getScreenX( FEditConfig::PITCH_LENGTH*0.5
+    goal_area_x = screenX( FEditConfig::PITCH_LENGTH*0.5
                            - FEditConfig::GOAL_AREA_LENGTH );
     painter.drawLine( right_x, goal_area_top_y, goal_area_x, goal_area_top_y );
     painter.drawLine( goal_area_x, goal_area_top_y, goal_area_x, goal_area_bottom_y );
@@ -221,16 +227,16 @@ FEditCanvas::drawField( QPainter & painter )
     // draw goal boxes
     painter.setPen( Qt::black );
     painter.setBrush( Qt::black );
-    const int goal_top_y = getScreenY( - FEditConfig::GOAL_WIDTH*0.5 );
+    const int goal_top_y = screenY( - FEditConfig::GOAL_WIDTH*0.5 );
     const int goal_size_x = scale( FEditConfig::GOAL_DEPTH );
     const int goal_size_y = scale( FEditConfig::GOAL_WIDTH );
     // left goal
-    painter.drawRect( getScreenX( - FEditConfig::PITCH_LENGTH*0.5
-                                  - FEditConfig::GOAL_DEPTH ),
-                      goal_top_y, 
+    painter.drawRect( screenX( - FEditConfig::PITCH_LENGTH*0.5
+                               - FEditConfig::GOAL_DEPTH ),
+                      goal_top_y,
                       goal_size_x, goal_size_y );
     // right goal
-    painter.drawRect( getScreenX( FEditConfig::PITCH_LENGTH*0.5 ) + 1,
+    painter.drawRect( screenX( FEditConfig::PITCH_LENGTH*0.5 ) + 1,
                       goal_top_y,
                       goal_size_x + 1, goal_size_y );
 }
@@ -274,14 +280,14 @@ FEditCanvas::drawContainedArea( QPainter & painter )
 
         QPointArray vertices( 3 );
         vertices.setPoint( 0,
-                           getScreenX( tri->vertex( 0 )->pos().x ),
-                           getScreenY( tri->vertex( 0 )->pos().y ) );
+                           screenX( tri->vertex( 0 )->pos().x ),
+                           screenY( tri->vertex( 0 )->pos().y ) );
         vertices.setPoint( 1,
-                           getScreenX( tri->vertex( 1 )->pos().x ),
-                           getScreenY( tri->vertex( 1 )->pos().y ) );
+                           screenX( tri->vertex( 1 )->pos().x ),
+                           screenY( tri->vertex( 1 )->pos().y ) );
         vertices.setPoint( 2,
-                           getScreenX( tri->vertex( 2 )->pos().x ),
-                           getScreenY( tri->vertex( 2 )->pos().y ) );
+                           screenX( tri->vertex( 2 )->pos().x ),
+                           screenY( tri->vertex( 2 )->pos().y ) );
 
         painter.drawConvexPolygon( vertices );
 
@@ -293,8 +299,8 @@ FEditCanvas::drawContainedArea( QPainter & painter )
 
         painter.setPen( Qt::cyan );
         painter.setBrush( Qt::cyan );
-        painter.drawRect( getScreenX( center.x ) - 1,
-                          getScreenY( center.y ) - 1,
+        painter.drawRect( screenX( center.x ) - 1,
+                          screenY( center.y ) - 1,
                           3, 3 );
 #if 0
         center = rcsc::Triangle2D::incenter( tri->vertex( 0 )->pos(),
@@ -303,8 +309,8 @@ FEditCanvas::drawContainedArea( QPainter & painter )
 
         painter.setPen( Qt::red );
         painter.setBrush( Qt::red );
-        painter.drawRect( getScreenX( center.x ) - 1,
-                          getScreenY( center.y ) - 1,
+        painter.drawRect( screenX( center.x ) - 1,
+                          screenY( center.y ) - 1,
                           3, 3 );
 
 
@@ -314,8 +320,8 @@ FEditCanvas::drawContainedArea( QPainter & painter )
 
         painter.setPen( Qt::red );
         painter.setBrush( Qt::red );
-        painter.drawRect( getScreenX( center.x ) - 1,
-                          getScreenY( center.y ) - 1,
+        painter.drawRect( screenX( center.x ) - 1,
+                          screenY( center.y ) - 1,
                           3, 3 );
 #endif
     }
@@ -359,8 +365,8 @@ FEditCanvas::drawTrainingData( QPainter & painter )
               train_it != train_end;
               ++train_it )
         {
-            int x = getScreenX( train_it->ball_.x );
-            int y = getScreenY( train_it->ball_.y );
+            int x = screenX( train_it->ball_.x );
+            int y = screenY( train_it->ball_.y );
             //painter.DrawCircle( x, y, r );
             painter.drawLine( x - r, y - r,
                               x + r, y + r );
@@ -394,10 +400,10 @@ FEditCanvas::drawTrainingData( QPainter & painter )
           it != end;
           ++it )
     {
-        painter.drawLine( getScreenX( it->second->vertex( 0 )->pos().x ),
-                          getScreenY( it->second->vertex( 0 )->pos().y ),
-                          getScreenX( it->second->vertex( 1 )->pos().x ),
-                          getScreenY( it->second->vertex( 1 )->pos().y ) );
+        painter.drawLine( screenX( it->second->vertex( 0 )->pos().x ),
+                          screenY( it->second->vertex( 0 )->pos().y ),
+                          screenX( it->second->vertex( 1 )->pos().x ),
+                          screenY( it->second->vertex( 1 )->pos().y ) );
     }
 
     painter.setFont( M_player_font );
@@ -413,8 +419,8 @@ FEditCanvas::drawTrainingData( QPainter & painter )
           it != v_end;
           ++it )
     {
-        int ix = getScreenX( it->ball_.x );
-        int iy = getScreenY( it->ball_.y );
+        int ix = screenX( it->ball_.x );
+        int iy = screenY( it->ball_.y );
         //char buf[4];
         //std::snprintf( buf, 4, "%2d", ++count );
         painter.drawText( ix + radius, iy - radius,
@@ -441,8 +447,16 @@ FEditCanvas::drawPlayers( QPainter & painter )
         return;
     }
 
-    const int radius = scale( 1.2 );
+    const int radius = ( M_enlarged
+                         ? scale( 1.1 )
+                         : scale( 0.3 ) );
     const int diameter = radius * 2;;
+
+    const int kickable_radius = scale( 1.1 );
+    const int kickable_diameter = kickable_radius * 2;
+
+    const int catchable_radius = scale( 2.0 );
+
     const int selected_radius = radius + 3;
 
     ////////////////////////////////////////////////////////////
@@ -465,8 +479,8 @@ FEditCanvas::drawPlayers( QPainter & painter )
               it != ptr->getOppPlayersPos().end();
               ++it, ++unum )
         {
-            int ix = getScreenX( it->x );
-            int iy = getScreenY( it->y );
+            int ix = screenX( it->x );
+            int iy = screenY( it->y );
             if ( selection == it )
             {
                 painter.setPen( M_select_pen );
@@ -487,7 +501,7 @@ FEditCanvas::drawPlayers( QPainter & painter )
             //std::snprintf( buf, 4, "%2d", unum );
             painter.DrawText( ix + radius, iy - radius,
                               QString().sprintf( "%2d", unum ) );
-                              //QString::fromAscii( buf ) );
+            //QString::fromAscii( buf ) );
 
         }
     }
@@ -506,9 +520,20 @@ FEditCanvas::drawPlayers( QPainter & painter )
               it != ptr->ourPlayers().end();
               ++it, ++unum )
         {
-            int ix = getScreenX( it->x );
-            int iy = getScreenY( it->y );
-            if ( f->isMirrorType( unum ) )
+            int ix = screenX( it->x );
+            int iy = screenY( it->y );
+            if ( selection == it )
+            {
+                painter.setPen( M_select_pen );
+                painter.setBrush( f->isMirrorType( unum )
+                                  ? M_mirror_brush
+                                  : M_left_team_brush );
+                painter.drawEllipse( ix - selected_radius,
+                                     iy - selected_radius,
+                                     selected_radius * 2,
+                                     selected_radius * 2 );
+            }
+            else if ( f->isMirrorType( unum ) )
             {
                 painter.setPen( M_player_pen );
                 painter.setBrush( M_mirror_brush );
@@ -517,15 +542,6 @@ FEditCanvas::drawPlayers( QPainter & painter )
                                      diameter,
                                      diameter );
             }
-            else if ( selection == it )
-            {
-                painter.setPen( M_select_pen );
-                painter.setBrush( M_left_team_brush );
-                painter.drawEllipse( ix - selected_radius,
-                                     iy - selected_radius,
-                                     selected_radius * 2,
-                                     selected_radius * 2 );
-            }
             else
             {
                 painter.setPen( M_player_pen );
@@ -535,12 +551,29 @@ FEditCanvas::drawPlayers( QPainter & painter )
                                      diameter,
                                      diameter );
             }
-            //char buf[4];
-            //std::snprintf( buf, 4, "%2d", unum );
+
+            bool goalie = ( f->getRoleName( unum ) == "Goalie" );
+            if ( ! M_enlarged
+                 && ! goalie )
+            {
+                painter.setBrush( NoBrush );
+                painter.drawEllipse( ix - kickable_radius,
+                                     iy - kickable_radius,
+                                     kickable_diameter,
+                                     kickable_diameter );
+            }
+            else if ( goalie )
+            {
+                painter.setBrush( NoBrush );
+                painter.drawEllipse( ix - catchable_radius,
+                                     iy - catchable_radius,
+                                     catchable_radius * 2,
+                                     catchable_radius * 2 );
+            }
+
             painter.setPen( Qt::white );
             painter.drawText( ix + radius, iy - radius,
                               QString().sprintf( "%2d", unum ) );
-                              //QString::fromAscii( buf ) );
         }
     }
 }
@@ -569,14 +602,122 @@ FEditCanvas::drawBall( QPainter & painter )
         painter.setBrush( Qt::lightGray );
     }
 
-    int radius = ( ptr->getSelectType() == FEditData::SELECT_BALL
+    int radius = 1;
+    if ( M_enlarged )
+    {
+        radius = ( ptr->getSelectType() == FEditData::SELECT_BALL
                    ? scale( 1.0 )
                    : scale( 0.7 ) );
+    }
+    else
+    {
+        radius = ( ptr->getSelectType() == FEditData::SELECT_BALL
+                   ? scale( 0.2 )
+                   : scale( 0.085 ) );
+    }
 
-    painter.drawEllipse( getScreenX( ptr->ball().x ) - radius,
-                         getScreenY( ptr->ball().y ) - radius,
+
+    int ix = screenX( ptr->ball().x );
+    int iy = screenY( ptr->ball().y );
+    painter.drawEllipse( ix - radius,
+                         iy - radius,
                          radius * 2,
                          radius * 2 );
+
+    if ( ! M_enlarged
+         && ptr->getSelectType() != FEditData::SELECT_BALL )
+    {
+        painter.setBrush( Qt::NoBrush );
+
+        int kickable_radius = scale( 1.085 );
+        painter.drawEllipse( ix - kickable_radius,
+                             iy - kickable_radius,
+                             kickable_radius * 2,
+                             kickable_radius * 2 );
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+FEditCanvas::setFocusPoint( const QPoint & pos )
+{
+    M_focus_point.x = fieldX( pos.x() );
+    M_focus_point.y = fieldY( pos.y() );
+
+    updateSize();
+
+    this->update();
+
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+FEditCanvas::zoomIn()
+{
+    M_field_scale *= 1.5;
+    M_zoomed = true;
+
+    this->update();
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+FEditCanvas::zoomOut()
+{
+    M_field_scale /= 1.5;
+    M_zoomed = true;
+
+    this->update();
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+FEditCanvas::fitSize()
+{
+    M_zoomed = false;
+    M_focus_point.assign( 0.0, 0.0 );
+    updateSize();
+
+    this->update();
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+FEditCanvas::toggleEnlarge( bool on )
+{
+    M_enlarged = on;
+
+    this->update();
+}
+
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+FEditCanvas::mouseDoubleClickEvent( QMouseEvent * event )
+{
+    if ( event->button() == Qt::LeftButton )
+    {
+        setFocusPoint( event->pos() );
+        this->update();
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -590,11 +731,18 @@ FEditCanvas::mousePressEvent( QMouseEvent * event )
     {
         M_mouse_state[0].pressed( event->pos() );
 
-        if ( boost::shared_ptr< FEditData > ptr = M_data_ptr.lock() )
+        if ( event->state() & Qt::ControlButton )
         {
-            ptr->selectObject( getFieldX( event->pos().x() ), 
-                               getFieldY( event->pos().y() ) );
-            this->update();
+
+        }
+        else
+        {
+            if ( boost::shared_ptr< FEditData > ptr = M_data_ptr.lock() )
+            {
+                ptr->selectObject( fieldX( event->pos().x() ),
+                                   fieldY( event->pos().y() ) );
+                this->update();
+            }
         }
     }
     else if ( event->button() == Qt::MidButton )
@@ -609,8 +757,8 @@ FEditCanvas::mousePressEvent( QMouseEvent * event )
         {
             if ( ptr->isBallDraggable() )
             {
-                ptr->moveBallTo( getFieldX( event->pos().x() ),
-                                 getFieldY( event->pos().y() ) );
+                ptr->moveBallTo( fieldX( event->pos().x() ),
+                                 fieldY( event->pos().y() ) );
                 this->update();
                 emit objectMoved();
             }
@@ -631,8 +779,8 @@ FEditCanvas::mouseReleaseEvent( QMouseEvent * event )
 
         if ( boost::shared_ptr< FEditData > ptr = M_data_ptr.lock() )
         {
-            ptr->releaseObject( getFieldX( event->pos().x() ),
-                                getFieldY( event->pos().y() ) );
+            ptr->releaseObject( fieldX( event->pos().x() ),
+                                fieldY( event->pos().y() ) );
             this->update();
         }
     }
@@ -654,19 +802,29 @@ void
 FEditCanvas::mouseMoveEvent( QMouseEvent * event )
 {
     QPoint point = event->pos();
-    for ( int i = 0; i < 3; ++i )
-    {
-        M_mouse_state[i].moved( point );
-    }
 
-    double field_x = getFieldX( point.x() );
-    double field_y = getFieldY( point.y() );
+    double field_x = fieldX( point.x() );
+    double field_y = fieldY( point.y() );
     //char buf[32];
     //std::snprintf( buf, 32, "(%.2f %.2f)", field_x, field_y );
 
     if ( M_mouse_state[0].isDragged() )
     {
         boost::shared_ptr< FEditData > ptr = M_data_ptr.lock();
+
+        if ( event->state() & Qt::ControlButton
+             || ( ptr
+                  && ptr->getSelectType() == FEditData::NO_SELECT )
+             )
+        {
+            int new_x = screenX( focusPoint().x );
+            int new_y = screenY( focusPoint().y );
+            new_x -= ( point.x() - M_mouse_state[0].draggedPoint().x() );
+            new_y -= ( point.y() - M_mouse_state[0].draggedPoint().y() );
+            setFocusPoint( QPoint( new_x, new_y ) );
+            this->update();
+        }
+
         if ( ptr
              && ptr->getSelectType() != FEditData::NO_SELECT )
         {
@@ -677,8 +835,12 @@ FEditCanvas::mouseMoveEvent( QMouseEvent * event )
         }
     }
 
+    for ( int i = 0; i < 3; ++i )
+    {
+        M_mouse_state[i].moved( point );
+    }
+
     //emit pointerMoved( QString::fromAscii( buf ) );
     emit pointerMoved( QString().sprintf( "(%.2f %.2f)", field_x, field_y ) );
 
 }
-
