@@ -67,6 +67,7 @@ FEditData::FEditData()
     , M_filepath_train( "" )
     , M_modified( false )
     , M_training_data_changed( false )
+    , M_delete_mode( false )
     , M_our_dragged( 11, 0 )
     , M_our_players( 11 )
     , M_opp_players( 11 )
@@ -181,7 +182,7 @@ FEditData::backup( const std::string & filepath )
     {
         std::snprintf( time_str, 64, ".time-%ld", current );
     }
-    
+
     std::string backup_filepath = filepath + time_str;
 
     std::ifstream fin( filepath.c_str() );
@@ -193,7 +194,7 @@ FEditData::backup( const std::string & filepath )
         std::ostreambuf_iterator< char > out_itr( fout );
         std ::copy( in_itr, std::istreambuf_iterator< char >(),
                     out_itr );
-        
+
         fin.close();
         fout.close();
     }
@@ -325,9 +326,9 @@ FEditData::openTrainingData( const std::string & filepath )
     M_filepath_train = filepath;
     M_modified = false;
     M_training_data_changed = false;
-    
+
     updateTriangulation();
-    
+
     moveBallTo( 0.0, 0.0 );
     updatePlayerPosition();
 
@@ -394,7 +395,7 @@ FEditData::save( std::ostream & os )
     {
         return false;
     }
-     
+
     M_modified = false;
     return true;
 }
@@ -464,7 +465,7 @@ FEditData::saveTrainingData( std::ostream & os )
         }
         os << std::endl;
     }
-    
+
     if ( ! os )
     {
         return false;
@@ -493,6 +494,13 @@ FEditData::updatePlayerPosition()
         return;
     }
 
+
+    if ( M_delete_mode )
+    {
+        M_delete_mode = false;
+        return;
+    }
+
     // update all players' position using formation param
 
     const rcsc::Vector2D & bpos = M_ball;
@@ -516,36 +524,87 @@ FEditData::updatePlayerPosition()
 void
 FEditData::updateTriangulation()
 {
-    rcsc::Rect2D pitch( - FEditConfig::PITCH_LENGTH * 0.5,
-                        - FEditConfig::PITCH_WIDTH * 0.5,
-                        FEditConfig::PITCH_LENGTH,
-                        FEditConfig::PITCH_WIDTH );
-    M_triangulation.init( pitch );
-    /*
-      M_triangulation.addVertex( 0.0, 0.0 );
-      M_triangulation.addVertex( pitch.topLeft() );
-      M_triangulation.addVertex( pitch.bottomLeft() );
-      M_triangulation.addVertex( pitch.bottomRight() );
-      M_triangulation.addVertex( pitch.topRight() );
-    */
-    const std::list< rcsc::Formation::Snapshot >::const_iterator end
-        = trainingData().end();
-    for ( std::list< rcsc::Formation::Snapshot >::const_iterator it
-              = trainingData().begin();
-          it != end;
-          ++it )
+    const rcsc::Rect2D pitch( - FEditConfig::PITCH_LENGTH * 0.5,
+                              - FEditConfig::PITCH_WIDTH * 0.5,
+                              FEditConfig::PITCH_LENGTH,
+                              FEditConfig::PITCH_WIDTH );
+#if 0
+    if ( M_formation
+         && M_formation->methodName() == rcsc::FormationDT::name() )
     {
-        M_triangulation.addVertex( it->ball_ );
-        /*
-          if ( it->ball_.absY() > 1.0 )
-          {
-          M_triangulation.addVertex( it->ball_.x,
-          it->ball_.y * -1.0 );
-          }
-        */
-    }
+        rcsc::FormationDT tmp_formation;
+        tmp_formation.createDefaultParam();
 
-    M_triangulation.compute();
+        for ( int idx = 0; idx < trainingData().size(); ++idx )
+        {
+            const std::list< rcsc::Formation::Snapshot >::iterator end
+                = M_training_data.end();
+
+            std::list< rcsc::Formation::Snapshot > tmp_data;
+
+            int check_idx = 0;
+            std::list< rcsc::Formation::Snapshot >::iterator check_it = end;
+            for ( std::list< rcsc::Formation::Snapshot >::iterator it
+                      = M_training_data.begin();
+                  it != end;
+                  ++it, ++check_idx )
+            {
+                if ( check_idx == idx )
+                {
+                    check_it = it;
+                    continue;
+                }
+
+                tmp_data.push_back( *it );
+            }
+
+            if ( check_it == end )
+            {
+                std::cerr << __FILE__ << ":" << __LINE__
+                          << " ***ERROR*** index = " << idx
+                          << std::endl;
+                continue;
+            }
+
+            tmp_formation.train( tmp_data );
+
+            bool very_near = true;
+            for ( int p = 0; p < 11; ++p )
+            {
+                rcsc::Vector2D pos = tmp_formation.getPosition( p + 1, check_it->ball_ );
+                if ( pos.dist( check_it->players_[p] ) > 0.5 )
+                {
+                    very_near = false;
+                    break;
+                }
+            }
+
+            if ( very_near )
+            {
+                std::cerr << "Removed data. index=" << idx
+                          << " ball=" << check_it->ball_
+                          << std::endl;
+                M_training_data.erase( check_it );
+                --idx;
+            }
+        }
+    }
+#endif
+    {
+        M_triangulation.init( pitch );
+
+        const std::list< rcsc::Formation::Snapshot >::const_iterator end
+            = trainingData().end();
+        for ( std::list< rcsc::Formation::Snapshot >::const_iterator it
+                  = trainingData().begin();
+              it != end;
+              ++it )
+        {
+            M_triangulation.addVertex( it->ball_ );
+        }
+
+        M_triangulation.compute();
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -821,7 +880,7 @@ FEditData::recordTrainingData()
           it != M_training_data.end();
           ++it )
     {
-        if ( it->ball_.dist( M_ball ) < 2.0 )
+        if ( it->ball_.dist( M_ball ) < 0.5 )
         {
             return std::string( "*** WARNING ***"
                                 " Exist too near recorded position!" );
@@ -852,6 +911,11 @@ FEditData::recordTrainingData()
 bool
 FEditData::focusTrainingData( const int idx )
 {
+    if ( idx <= 0 )
+    {
+        return false;
+    }
+
     std::list< rcsc::Formation::Snapshot >::iterator it = M_training_data.begin();
 
     int count = 1;
@@ -930,18 +994,22 @@ FEditData::deleteTrainingData( const int idx )
         {
             M_training_data.erase( it );
             M_training_data_changed = true;
+            M_delete_mode = true;
             break;
         }
         ++count;
         ++it;
     }
 
-    updateTriangulation();
-
-    if ( M_formation
-         && M_formation->methodName() == rcsc::FormationDT::name() )
+    if ( M_delete_mode )
     {
-        train();
+        updateTriangulation();
+
+        if ( M_formation
+             && M_formation->methodName() == rcsc::FormationDT::name() )
+        {
+            train();
+        }
     }
 
     return true;
