@@ -62,6 +62,7 @@
 #include "xpm/train.xpm"
 #include "xpm/record.xpm"
 #include "xpm/replace.xpm"
+#include "xpm/reverse.xpm"
 #include "xpm/save.xpm"
 
 #ifndef PACKAGENAME
@@ -115,12 +116,12 @@ MainWindow::MainWindow()
         this->showFullScreen();
     }
 
+    connect( M_editor_dialog, SIGNAL( viewUpdated() ),
+             M_editor_canvas, SLOT( update() ) );
     connect( M_editor_canvas, SIGNAL( objectMoved() ),
              M_editor_dialog, SLOT( updateData() ) );
-
     connect( M_editor_dialog, SIGNAL( shown( bool ) ),
              M_show_edit_dialog_act, SLOT( setOn( bool ) ) );
-
 }
 
 /*-------------------------------------------------------------------*/
@@ -142,11 +143,29 @@ MainWindow::~MainWindow()
 void
 MainWindow::init()
 {
-    M_editor_dialog->show();
+//     M_editor_dialog->show();
 
-    QSize size = M_editor_dialog->size();
-    M_editor_dialog->setMinimumSize( size );
-    M_editor_dialog->setMaximumSize( size );
+//     QSize size = M_editor_dialog->size();
+//     M_editor_dialog->setMinimumSize( size );
+//     M_editor_dialog->setMaximumSize( size );
+
+    bool conf_opened = false;
+    if ( ! FEditConfig::instance().confFile().empty() )
+    {
+        if ( ! FEditConfig::instance().dataFile().empty() )
+        {
+            openConfFile( FEditConfig::instance().confFile() );
+        }
+        else
+        {
+            open( FEditConfig::instance().confFile() );
+        }
+    }
+
+    if ( ! FEditConfig::instance().dataFile().empty() )
+    {
+        openDataFile( FEditConfig::instance().dataFile() );
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -207,6 +226,7 @@ MainWindow::createActions()
     createActionsFile();
     createActionsMode();
     createActionsData();
+    createActionsView();
     createActionsHelp();
 }
 
@@ -239,8 +259,8 @@ MainWindow::createActionsFile()
                                     this );
     M_open_train_act->setAccel( tr( "Ctrl+Alt+O" ) );
     M_open_train_act->setStatusTip( tr( "Open training data file" ) );
-    connect( M_open_train_act, SIGNAL( activated() ), 
-             this, SLOT( openTrainingData() ) );
+    connect( M_open_train_act, SIGNAL( activated() ),
+             this, SLOT( openData() ) );
     //
     M_save_all_act = new QAction( QIconSet( QPixmap( save_xpm ) ),
                                   tr( "&Save all" ),
@@ -266,14 +286,14 @@ MainWindow::createActionsFile()
                               QKeySequence(),
                               this );
     M_save_train_act->setStatusTip( tr( "Save training data" ) );
-    connect( M_save_train_act, SIGNAL( activated() ), 
+    connect( M_save_train_act, SIGNAL( activated() ),
              this, SLOT( saveTrainingData() ) );
     //
     M_save_train_as_act = new QAction( tr( "&Save training data as..." ),
                               QKeySequence(),
                               this );
     M_save_train_as_act->setStatusTip( tr( "Save training data to the new file" ) );
-    connect( M_save_train_as_act, SIGNAL( activated() ), 
+    connect( M_save_train_as_act, SIGNAL( activated() ),
              this, SLOT( saveTrainingDataAs() ) );
     //
     M_exit_act = new QAction( tr( "&Quit" ),
@@ -295,6 +315,7 @@ MainWindow::createActionsMode()
                                           tr( "&Ball Drag" ),
                                           QKeySequence(),
                                           this );
+    M_toggle_ball_drag_act->setAccel( tr( "Ctrl+B" ) );
     M_toggle_ball_drag_act->setStatusTip( tr( "Toggle ball drag mode." ) );
     M_toggle_ball_drag_act->setToggleAction( true );
     M_toggle_ball_drag_act->setOn( true );
@@ -305,6 +326,7 @@ MainWindow::createActionsMode()
                                                  tr( "&Auto Move" ),
                                                  QKeySequence(),
                                                  this );
+    M_toggle_player_auto_move_act->setAccel( tr( "Ctrl+P" ) );
     M_toggle_player_auto_move_act->setStatusTip( tr( "Toggle player auto move mode." ) );
     M_toggle_player_auto_move_act->setToggleAction( true );
     M_toggle_player_auto_move_act->setOn( true );
@@ -312,11 +334,12 @@ MainWindow::createActionsMode()
              this, SLOT( togglePlayerAutoMove( bool ) ) );
     //
     M_show_edit_dialog_act = new QAction( tr( "Show Edit Dialog" ),
-                                     QKeySequence(),
-                                     this );
+                                          QKeySequence(),
+                                          this );
+    M_show_edit_dialog_act->setAccel( tr( "Ctrl+D" ) );
     M_show_edit_dialog_act->setStatusTip( tr( "Show/Hide edit dialog box." ) );
     M_show_edit_dialog_act->setToggleAction( true );
-    M_show_edit_dialog_act->setOn( true );
+    M_show_edit_dialog_act->setOn( false );
     connect( M_show_edit_dialog_act, SIGNAL( toggled( bool ) ),
              this, SLOT( showEditDialog( bool ) ) );
 }
@@ -346,6 +369,15 @@ MainWindow::createActionsData()
     connect( M_delete_data_act, SIGNAL( activated() ),
              this, SLOT( deleteData() ) );
     //
+    M_reverse_y_act = new QAction( QIconSet( QPixmap( reverse_xpm ) ),
+                                   tr( "ReverseY" ),
+                                   QKeySequence(),
+                                   this );
+    M_reverse_y_act->setAccel( tr( "Ctrl+R" ) );
+    M_reverse_y_act->setStatusTip( tr( "Reverse Y positions." ) );
+    connect( M_reverse_y_act, SIGNAL( activated() ),
+             this, SLOT( reverseY() ) );
+    //
     M_train_act = new QAction( QIconSet( QPixmap( train_xpm ) ),
                                tr( "Train" ),
                                QKeySequence(),
@@ -367,6 +399,50 @@ MainWindow::createActionsData()
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+MainWindow::createActionsView()
+{
+    M_zoom_in_act = new QAction( tr( "Zoom In" ),
+                                 QKeySequence(),
+                                 this );
+    M_zoom_in_act->setAccel( Qt::Key_Z );
+    M_zoom_in_act->setStatusTip( tr( "Zoom In" ) );
+    connect( M_zoom_in_act, SIGNAL( activated() ),
+             M_editor_canvas, SLOT( zoomIn() ) );
+
+    M_zoom_out_act = new QAction( tr( "Zoom Out" ),
+                                  QKeySequence(),
+                                  this );
+    M_zoom_out_act->setAccel( Qt::Key_X );
+    M_zoom_out_act->setStatusTip( tr( "Zoom Out" ) );
+    connect( M_zoom_out_act, SIGNAL( activated() ),
+             M_editor_canvas, SLOT( zoomOut() ) );
+
+    M_fit_act = new QAction( tr( "Fit Size" ),
+                                  QKeySequence(),
+                                  this );
+    M_fit_act->setAccel( Qt::Key_I );
+    M_fit_act->setStatusTip( tr( "Fit Size" ) );
+    connect( M_fit_act, SIGNAL( activated() ),
+             M_editor_canvas, SLOT( fitSize() ) );
+
+    M_toggle_enlarge_act = new QAction( tr( "Toggle Enlarge" ),
+                                  QKeySequence(),
+                                  this );
+    M_toggle_enlarge_act->setAccel( Qt::Key_E );
+    M_toggle_enlarge_act->setStatusTip( tr( "Toggle Enlarge Status" ) );
+    M_toggle_enlarge_act->setToggleAction( true );
+    M_toggle_enlarge_act->setOn( true );
+    connect( M_toggle_enlarge_act, SIGNAL( toggled( bool ) ),
+             M_editor_canvas, SLOT( toggleEnlarge( bool ) ) );
+
+
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 MainWindow::createActionsHelp()
@@ -387,7 +463,9 @@ void
 MainWindow::createMenus()
 {
     createMenuFile();
+    createMenuEdit();
     createMenuMode();
+    createMenuView();
     createMenuHelp();
 }
 
@@ -425,6 +503,23 @@ MainWindow::createMenuFile()
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+MainWindow::createMenuEdit()
+{
+    QPopupMenu * menu = new QPopupMenu( this );
+
+    M_replace_data_act->addTo( menu );
+    M_delete_data_act->addTo( menu );
+
+    M_reverse_y_act->addTo( menu );
+
+    menuBar()->insertItem( tr( "&Edit" ), menu );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 MainWindow::createMenuMode()
@@ -444,6 +539,26 @@ MainWindow::createMenuMode()
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+MainWindow::createMenuView()
+{
+    QPopupMenu * menu = new QPopupMenu( this );
+
+    M_zoom_in_act->addTo( menu );
+    M_zoom_out_act->addTo( menu );
+    M_fit_act->addTo( menu );
+
+    menu->insertSeparator();
+
+    M_toggle_enlarge_act->addTo( menu );
+
+    menuBar()->insertItem( tr( "&View" ), menu );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 MainWindow::createMenuHelp()
@@ -471,6 +586,7 @@ MainWindow::createToolBars()
 
     M_replace_data_act->addTo( M_tool_bar );
     M_delete_data_act->addTo( M_tool_bar );
+    M_reverse_y_act->addTo( M_tool_bar );
 
     M_index_spin_box = new QSpinBox( M_tool_bar );
     M_index_spin_box->setWrapping( true );
@@ -535,9 +651,6 @@ MainWindow::createEditDialog()
 {
     M_editor_dialog = new FEditDialog( this );
 
-    connect( M_editor_dialog, SIGNAL( viewUpdated() ),
-             M_editor_canvas, SLOT( update() ) );
-
 }
 
 /*-------------------------------------------------------------------*/
@@ -860,11 +973,41 @@ MainWindow::open()
 void
 MainWindow::open( const QString & filepath )
 {
-    if ( filepath.isEmpty() )
+    if ( ! openConfFile( filepath ) )
     {
         return;
     }
 
+    int result = QMessageBox::information( this,
+                                           tr( "Option" ),
+                                           tr( "Do you open a training data, too?" ),
+                                           QMessageBox::Yes,
+                                           QMessageBox::No );
+    if ( result == QMessageBox::Yes )
+    {
+        openData();
+    }
+
+    emit viewUpdated();
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+MainWindow::openConfFile( const QString & filepath )
+{
+    if ( filepath.isEmpty() )
+    {
+        QMessageBox::warning( this,
+                              tr( "Warning" ),
+                              tr( "Empty file path." ),
+                              QMessageBox::Ok,
+                              QMessageBox::NoButton );
+        return false;
+    }
+
     QFileInfo fileinfo( filepath );
 
     if ( ! fileinfo.exists()
@@ -875,7 +1018,7 @@ MainWindow::open( const QString & filepath )
                               tr( "No such a file or not readable. " ) + filepath,
                               QMessageBox::Ok,
                               QMessageBox::NoButton );
-        return;
+        return false;
     }
 
     M_editor_data = boost::shared_ptr< FEditData >( new FEditData() );
@@ -887,7 +1030,7 @@ MainWindow::open( const QString & filepath )
                               tr( "Failed to open the file " ) + filepath,
                               QMessageBox::Ok,
                               QMessageBox::NoButton );
-        return;
+        return false;
     }
 
     if ( ! M_editor_data->formation() )
@@ -898,7 +1041,7 @@ MainWindow::open( const QString & filepath )
                               tr( "Failed to create a formation from " ) + filepath,
                               QMessageBox::Ok,
                               QMessageBox::NoButton );
-        return;
+        return false;
     }
 
     // set window title
@@ -912,17 +1055,7 @@ MainWindow::open( const QString & filepath )
     M_editor_data->moveBallTo( 0.0, 0.0 );
     M_editor_dialog->updateData();
 
-    int result = QMessageBox::information( this, 
-                                           tr( "Option" ),
-                                           tr( "Do you open a training data, too?" ),
-                                           QMessageBox::Yes,
-                                           QMessageBox::No );
-    if ( result == QMessageBox::Yes )
-    {
-        openTrainingData();
-    }
-
-    emit viewUpdated();
+    return true;
 }
 
 /*-------------------------------------------------------------------*/
@@ -930,10 +1063,15 @@ MainWindow::open( const QString & filepath )
 
 */
 void
-MainWindow::openTrainingData()
+MainWindow::openData()
 {
     if ( ! M_editor_data )
     {
+        QMessageBox::warning( this,
+                              tr( "Warning" ),
+                              tr( "Data specified, but no formation." ),
+                              QMessageBox::Ok,
+                              QMessageBox::NoButton );
         return;
     }
 
@@ -944,19 +1082,34 @@ MainWindow::openTrainingData()
                                                      this,
                                                      tr( "Open Training Data" ),
                                                      tr( "Choose a file name to open" ) );
-    openTrainingData( filepath );
+    openDataFile( filepath );
 }
 
 /*-------------------------------------------------------------------*/
 /*!
 
 */
-void
-MainWindow::openTrainingData( const QString & filepath )
+bool
+MainWindow::openDataFile( const QString & filepath )
 {
     if ( filepath.isEmpty() )
     {
-        return;
+        QMessageBox::warning( this,
+                              tr( "Warning" ),
+                              tr( "Empty file path." ),
+                              QMessageBox::Ok,
+                              QMessageBox::NoButton );
+        return false;
+    }
+
+    if ( ! M_editor_data )
+    {
+        QMessageBox::warning( this,
+                              tr( "Warning" ),
+                              tr( "Data specified, but no formation." ),
+                              QMessageBox::Ok,
+                              QMessageBox::NoButton );
+        return false;
     }
 
     QFileInfo fileinfo( filepath );
@@ -969,7 +1122,7 @@ MainWindow::openTrainingData( const QString & filepath )
                               tr( "No such a file or not readable. " ) + filepath,
                               QMessageBox::Ok,
                               QMessageBox::NoButton );
-        return;
+        return false;
     }
 
     if ( ! M_editor_data->openTrainingData( filepath.ascii() ) )
@@ -979,13 +1132,15 @@ MainWindow::openTrainingData( const QString & filepath )
                               tr( "Failed to read the file " ) + filepath,
                               QMessageBox::Ok,
                               QMessageBox::NoButton );
-        return;
+        return false;
 
     }
 
     setTrainingDataSize();
 
     emit viewUpdated();
+
+    return true;
 }
 
 /*-------------------------------------------------------------------*/
@@ -1056,7 +1211,7 @@ MainWindow::saveAll()
 void
 MainWindow::save()
 {
-    if ( ! M_editor_data 
+    if ( ! M_editor_data
          || ! M_editor_data->formation() )
     {
         return;
@@ -1078,7 +1233,7 @@ MainWindow::save()
 void
 MainWindow::saveAs()
 {
-    if ( ! M_editor_data 
+    if ( ! M_editor_data
          || ! M_editor_data->formation() )
     {
         return;
@@ -1143,7 +1298,7 @@ MainWindow::saveTrainingData()
 void
 MainWindow::saveTrainingDataAs()
 {
-    if ( ! M_editor_data 
+    if ( ! M_editor_data
          || M_editor_data->trainingData().empty() )
     {
         return;
@@ -1194,7 +1349,7 @@ MainWindow::toggleBallDrag( bool on )
 /*!
 
 */
-void 
+void
 MainWindow::togglePlayerAutoMove( bool on )
 {
     std::cerr << "toggle player auto move " << on << std::endl;
@@ -1209,12 +1364,16 @@ MainWindow::togglePlayerAutoMove( bool on )
 /*!
 
 */
-void 
+void
 MainWindow::showEditDialog( bool on )
 {
     if ( on )
     {
         M_editor_dialog->show();
+
+        QSize size = M_editor_dialog->size();
+        M_editor_dialog->setMinimumSize( size );
+        M_editor_dialog->setMaximumSize( size );
     }
     else
     {
@@ -1249,7 +1408,7 @@ MainWindow::recordData()
     }
 
     setTrainingDataSize();
-    
+
     emit viewUpdated();
 }
 
@@ -1260,8 +1419,6 @@ MainWindow::recordData()
 void
 MainWindow::replaceData()
 {
-    std::cerr << "replaceData" << std::endl;
-
     if ( ! M_editor_data )
     {
         return;
@@ -1297,11 +1454,12 @@ MainWindow::deleteData()
 
 */
 void
-MainWindow::train()
+MainWindow::reverseY()
 {
     if ( M_editor_data )
     {
-        M_editor_data->train();
+        M_editor_data->reverseY();
+        emit viewUpdated();
     }
 }
 
@@ -1310,11 +1468,12 @@ MainWindow::train()
 
 */
 void
-MainWindow::reverseY()
+MainWindow::train()
 {
     if ( M_editor_data )
     {
-        M_editor_data->reverseY();
+        M_editor_data->train();
+        emit viewUpdated();
     }
 }
 
@@ -1340,7 +1499,7 @@ void
 MainWindow::changeDataIndex( int idx )
 {
     if ( M_index_spin_box->value() != idx
-         && 0 < idx 
+         && 0 < idx
          && idx <= M_index_spin_box->maxValue() )
     {
         M_index_spin_box->setValue( idx );
