@@ -83,6 +83,9 @@ private:
     Point M_field_center; //!< the screen point of field center
     double M_field_scale; //!< field scale rate
 
+    bool M_reverse_side; //!< reverse left/right
+    bool M_player_reverse_draw; //!< reverse the order of player draw
+
     int M_score_board_font_size;
     int M_score_board_height; //!< screen height of score board
 
@@ -152,6 +155,10 @@ private:
     bool M_show_debug_view_figure;
     bool M_show_debug_view_target;
     bool M_show_debug_view_message;
+
+    // debug log view
+    bool M_show_debug_log_view;
+
 public:
     //! constructor
     ViewConfig();
@@ -199,6 +206,28 @@ public:
           return M_score_board_height;
       }
 
+    bool reverseSide() const
+      {
+          return M_reverse_side;
+      }
+    void toggleReverseSide()
+      {
+          M_reverse_side = ! M_reverse_side;
+      }
+    double reverseValue() const
+      {
+          return ( M_reverse_side ? -1.0 : 1.0 );
+      }
+
+    bool playerReverseDraw() const
+      {
+          return M_player_reverse_draw;
+      }
+    void togglePlayerReverseDraw()
+      {
+          M_player_reverse_draw = ! M_player_reverse_draw;
+      }
+
     //------------------------------------------------------
 
     void zoomIn();
@@ -611,6 +640,19 @@ public:
           return M_show_debug_view_message;
       }
 
+    //////////////////////////////////////////////////////////
+    // debug log view options
+
+    void toggleShowDebugLogView()
+      {
+          M_show_debug_log_view = ! M_show_debug_log_view;
+      }
+    bool isShownDebugLogView() const
+      {
+          return M_show_debug_log_view;
+      }
+
+
     //////////////////////////////////////////////////////////
     /*!
       \brief scale input length to screen length.
@@ -631,7 +673,7 @@ public:
       \param x real point
       \return screen point
     */
-    int getScreenX( const double & x ) const
+    int screenX( const double & x ) const
       {
           return fieldCenter().x + scale( x );
       }
@@ -640,7 +682,7 @@ public:
       \param y real point
       \return screen point
     */
-    int getScreenY( const double & y ) const
+    int screenY( const double & y ) const
       {
           return fieldCenter().y + scale( y );
       }
@@ -650,7 +692,7 @@ public:
       \param x screen point value
       \return field real point value
      */
-    double getFieldX( const int x ) const
+    double fieldX( const int x ) const
       {
           return ( x - fieldCenter().x ) / fieldScale();
       }
@@ -660,7 +702,7 @@ public:
       \param y screen point value
       \return field real point value
      */
-    double getFieldY( const int y ) const
+    double fieldY( const int y ) const
       {
           return ( y - fieldCenter().y ) / fieldScale();
       }
@@ -670,10 +712,10 @@ public:
       \param point screen point value
       \return field real point value
      */
-    rcsc::Vector2D getFieldPoint( const Point & point ) const
+    rcsc::Vector2D fieldPoint( const Point & point ) const
       {
-          return rcsc::Vector2D( getFieldX( point.x ),
-                                 getFieldY( point.y ) );
+          return rcsc::Vector2D( fieldX( point.x ),
+                                 fieldY( point.y ) );
       }
 };
 
