@@ -46,6 +46,7 @@
 #include <rcsc/common/server_param.h>
 #include <rcsc/rcg/serializer.h>
 #include <rcsc/rcg/factory.h>
+#include <rcsc/types.h>
 
 #include <iterator>
 #include <sstream>
@@ -64,8 +65,7 @@ const std::string DEFAULT_DEBUG_VIEW_EXTENSION = ".log";
 ViewHolder::ViewHolder()
     : M_last_playmode( rcsc::PM_Null )
 {
-    rcsc::PlayerType default_type( rcsc::ServerParam::i() );
-    M_player_types.assign( 7, default_type );
+    M_player_types.assign( 1, rcsc::PlayerType( rcsc::ServerParam::i() ) );
 
     M_monitor_view_cont.reserve( 1024 * 8 );
 }
@@ -88,19 +88,23 @@ void
 ViewHolder::clear()
 {
     M_last_playmode = rcsc::PM_Null;
+
     std::memset( M_last_team_left.name, '\0', 16 );
     M_last_team_left.score = 0;
     std::memset( M_last_team_right.name, '\0', 16 );
     M_last_team_right.score = 0;
+
     M_score_change_indexes.clear();
+    M_penalty_scores_left.clear();
+    M_penalty_scores_right.clear();
+
     M_latest_view_data.reset();
     M_monitor_view_cont.clear();
 
     M_left_debug_view.clear();
     M_right_debug_view.clear();
 
-    rcsc::PlayerType default_type( rcsc::ServerParam::i() );
-    M_player_types.assign( 7, default_type );
+    M_player_types.assign( 1, rcsc::PlayerType( rcsc::ServerParam::i() ) );
 }
 
 /*-------------------------------------------------------------------*/
@@ -488,12 +492,11 @@ ViewHolder::pushBackLatestViewData()
   push back new data
 */
 bool
-ViewHolder::addMsgInfo( const short board,
+ViewHolder::addMsgInfo( const rcsc::rcg::Int16 board,
                         const std::string & msg )
 {
     //std::cerr << "ViewHolder::addMsgInfo" << std::endl;
-    std::cout << "recv msginfo_t: board = " << board
-              << " message = [" << msg << ']'
+    std::cout << "recv msginfo_t: message = [" << msg << ']'
               << std::endl;
     return true;
 }
@@ -517,7 +520,29 @@ ViewHolder::addDrawInfo( const rcsc::rcg::drawinfo_t & msg )
 bool
 ViewHolder::addPlayMode( const char pmode )
 {
-    M_last_playmode = static_cast< rcsc::PlayMode >( pmode );
+    rcsc::PlayMode playmode = static_cast< rcsc::PlayMode >( pmode );
+
+    if ( M_last_playmode != playmode )
+    {
+        if ( playmode == rcsc::PM_PenaltyScore_Left
+             || playmode == rcsc::PM_PenaltyMiss_Left )
+        {
+            long cycle = ( M_latest_view_data
+                           ? M_latest_view_data->cycle()
+                           : 0 );
+            M_penalty_scores_left.push_back( std::make_pair( cycle, playmode ) );
+        }
+        else if(  playmode == rcsc::PM_PenaltyScore_Right
+                  || playmode == rcsc::PM_PenaltyMiss_Right )
+        {
+            long cycle = ( M_latest_view_data
+                           ? M_latest_view_data->cycle()
+                           : 0 );
+            M_penalty_scores_right.push_back( std::make_pair( cycle, playmode ) );
+        }
+    }
+
+    M_last_playmode = playmode;
     return true;
 }
 
@@ -549,15 +574,20 @@ ViewHolder::addPlayerType( const rcsc::rcg::player_type_t & param )
 {
     //std::cerr << "ViewHolder::addPlayerType" << std::endl;
 
-    int idx = static_cast< int >( htons( param.id ) );
-    if ( idx < 0 || 6 < idx )
+    int id = static_cast< int >( htons( param.id ) );
+    if ( id < 0 )
     {
         std::cerr << "addPlayerType. over the array size" << std::endl;
         return false;
     }
 
-    M_player_types[idx] = rcsc::PlayerType( rcsc::ServerParam::i(),
-                                            param );
+    if ( id + 1 >= static_cast< int >( M_player_types.size() ) )
+    {
+        M_player_types.resize( id + 1, rcsc::PlayerType( rcsc::ServerParam::i() ) );
+    }
+
+    M_player_types[id] = rcsc::PlayerType( rcsc::ServerParam::i(),
+                                           param );
     return true;
 }
 
