@@ -87,8 +87,6 @@ DebugMessageWindow::DebugMessageWindow( QWidget * parent,
                                         MainData & main_data )
     : QMainWindow( parent )
     , M_main_data( main_data )
-    , M_debug_holder( new DebugLogHolder )
-    , M_level( 0xFFFF )
 {
     this->setWindowTitle( tr( "Debug Message" ) );
 
@@ -135,15 +133,8 @@ DebugMessageWindow::loadSettings()
         {
             bool enable = val.toBool();
 
-            int level = DebugLogData::LEVEL_1 << i;
-            if ( enable )
-            {
-                M_level |= level;
-            }
-            else
-            {
-                M_level &= ~level;
-            }
+            boost::int32_t level = DebugLogData::LEVEL_01 << i;
+            M_main_data.getDebugLogHolder().setLevel( level, enable );
 
             M_debug_level_act[i]->setChecked( enable );
         }
@@ -506,18 +497,20 @@ DebugMessageWindow::loadDebugLogDir( const rcsc::SideID side,
 
     if ( side == rcsc::LEFT )
     {
-        if ( M_debug_holder->setDir( ptr->leftTeam().name(),
-                                     M_tab_widget->currentIndex() + 1,
-                                     dir_path ) )
+        if ( M_main_data.getDebugLogHolder().setDir( ptr->leftTeam().name(),
+                                                     side,
+                                                     M_tab_widget->currentIndex() + 1,
+                                                     dir_path ) )
         {
             syncCycle();
         }
     }
     else if ( side == rcsc::RIGHT )
     {
-        if ( M_debug_holder->setDir( ptr->rightTeam().name(),
-                                     M_tab_widget->currentIndex() + 1,
-                                     dir_path ) )
+        if ( M_main_data.getDebugLogHolder().setDir( ptr->rightTeam().name(),
+                                                     side,
+                                                     M_tab_widget->currentIndex() + 1,
+                                                     dir_path ) )
         {
             syncCycle();
         }
@@ -694,7 +687,7 @@ DebugMessageWindow::syncCycle()
 
     std::cerr << "sync debug data cycle" << std::endl;
     // seek current cycle data
-    if ( ! M_debug_holder->seekData( M_tab_widget->currentIndex() + 1, ptr->cycle() ) )
+    if ( ! M_main_data.getDebugLogHolder().seekData( M_tab_widget->currentIndex() + 1, ptr->cycle() ) )
     {
         std::cerr << "No data! number = "
                   << M_tab_widget->currentIndex() + 1
@@ -712,7 +705,7 @@ DebugMessageWindow::syncCycle()
 void
 DebugMessageWindow::decrementCycle()
 {
-    if ( ! M_debug_holder->decDataCycle( M_tab_widget->currentIndex() + 1 ) )
+    if ( ! M_main_data.getDebugLogHolder().decDataCycle( M_tab_widget->currentIndex() + 1 ) )
     {
         return;
     }
@@ -727,7 +720,7 @@ DebugMessageWindow::decrementCycle()
 void
 DebugMessageWindow::incrementCycle()
 {
-    if ( ! M_debug_holder->incDataCycle( M_tab_widget->currentIndex() + 1 ) )
+    if ( ! M_main_data.getDebugLogHolder().incDataCycle( M_tab_widget->currentIndex() + 1 ) )
     {
         std::cerr << "Failed increment debug log" << std::endl;
         return;
@@ -743,16 +736,10 @@ DebugMessageWindow::incrementCycle()
 void
 DebugMessageWindow::toggleDebugLevel_1( bool checked )
 {
-    //M_level ^= DebugLogData::LEVEL_1; // reverse only 1 bit
+    //M_level ^= DebugLogData::LEVEL_01; // reverse only 1 bit
 
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_1;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_1;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_01,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -765,14 +752,8 @@ DebugMessageWindow::toggleDebugLevel_1( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_2( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_2;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_2;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_02,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -785,14 +766,8 @@ DebugMessageWindow::toggleDebugLevel_2( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_3( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_3;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_3;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_03,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -805,14 +780,8 @@ DebugMessageWindow::toggleDebugLevel_3( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_4( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_4;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_4;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_04,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -825,14 +794,8 @@ DebugMessageWindow::toggleDebugLevel_4( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_5( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_5;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_5;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_05,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -845,14 +808,8 @@ DebugMessageWindow::toggleDebugLevel_5( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_6( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_6;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_6;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_06,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -865,14 +822,8 @@ DebugMessageWindow::toggleDebugLevel_6( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_7( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_7;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_7;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_07,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -885,14 +836,8 @@ DebugMessageWindow::toggleDebugLevel_7( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_8( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_8;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_8;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_08,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -905,14 +850,8 @@ DebugMessageWindow::toggleDebugLevel_8( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_9( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_9;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_9;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_09,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -925,14 +864,8 @@ DebugMessageWindow::toggleDebugLevel_9( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_10( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_10;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_10;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_10,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -945,14 +878,8 @@ DebugMessageWindow::toggleDebugLevel_10( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_11( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_11;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_11;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_11,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -965,14 +892,8 @@ DebugMessageWindow::toggleDebugLevel_11( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_12( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_12;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_12;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_12,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -985,14 +906,8 @@ DebugMessageWindow::toggleDebugLevel_12( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_13( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_13;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_13;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_13,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -1005,14 +920,8 @@ DebugMessageWindow::toggleDebugLevel_13( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_14( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_14;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_14;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_14,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -1025,14 +934,8 @@ DebugMessageWindow::toggleDebugLevel_14( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_15( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_15;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_15;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_15,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -1045,14 +948,8 @@ DebugMessageWindow::toggleDebugLevel_15( bool checked )
 void
 DebugMessageWindow::toggleDebugLevel_16( bool checked )
 {
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_16;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_16;
-    }
+    M_main_data.getDebugLogHolder().setLevel( DebugLogData::LEVEL_16,
+                                              checked );
 
     updateMessage();
     emit configured();
@@ -1065,7 +962,7 @@ DebugMessageWindow::toggleDebugLevel_16( bool checked )
 void
 DebugMessageWindow::clearAll()
 {
-    M_debug_holder = boost::shared_ptr< DebugLogHolder >( new DebugLogHolder );
+    M_main_data.getDebugLogHolder().clear();
 
     for ( int i = 0; i < 11; ++i )
     {
@@ -1083,20 +980,21 @@ DebugMessageWindow::updateMessage()
     std::cerr << "DebuMessageWindow::updateMessage()" << std::endl;
 
     const DebugLogHolder::DataList * data_list
-        = M_debug_holder->getDataList( M_tab_widget->currentIndex() + 1 );
+        = M_main_data.getDebugLogHolder().getDataList( M_tab_widget->currentIndex() + 1 );
     if ( ! data_list )
     {
         std::cerr << "DebuMessageWindow::updateMessage() no data list" << std::endl;
         return;
     }
 
-    if ( M_level == 0 )
+    const boost::int32_t level = M_main_data.getDebugLogHolder().level();
+    if ( level == 0 )
     {
         std::cerr << "DebuMessageWindow::updateMessage() no debug level" << std::endl;
         return;
     }
 
-    const long cur_cycle = M_debug_holder->getCurrentCycle();
+    const long cur_cycle = M_main_data.getDebugLogHolder().getCurrentCycle();
 
     QTextEdit * text_edit = M_message[ M_tab_widget->currentIndex() ];
 
@@ -1130,15 +1028,15 @@ DebugMessageWindow::updateMessage()
         cycle_line += tr( " ------------------------------\n" );
         text_edit->append( cycle_line );
 
-        const DebugLogData::TextList::const_iterator text_end = (*data_it)->textList().end();
-        for ( DebugLogData::TextList::const_iterator text_it = (*data_it)->textList().begin();
+        const DebugLogData::TextCont::const_iterator text_end = (*data_it)->textCont().end();
+        for ( DebugLogData::TextCont::const_iterator text_it = (*data_it)->textCont().begin();
               text_it != text_end;
               ++text_it )
         {
             // level check
-            if ( M_level & text_it->first )
+            if ( level & text_it->level_ )
             {
-                main_buffer += QString::fromStdString( text_it->second );
+                main_buffer += QString::fromStdString( text_it->msg_ );
                 if ( ++n_line > 1000 )
                 {
                     // append message to text control
