@@ -191,8 +191,8 @@ DebugPainter::drawSelf( QPainter & painter,
     const DrawConfig & dconf = DrawConfig::instance();
 
     const double reverse = ( player_side == rcsc::RIGHT ? -1.0 : 1.0 );
-    const int ix = vconf.getScreenX( (double)self->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
-    const int iy = vconf.getScreenY( (double)self->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+    const int ix = vconf.screenX( (double)self->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+    const int iy = vconf.screenY( (double)self->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
     const int r = std::max( 2,
                             ( vconf.isEnlarged()
                               ? vconf.scale( 1.0 )
@@ -202,8 +202,8 @@ DebugPainter::drawSelf( QPainter & painter,
     if ( vconf.isShownDebugViewTarget()
          &&  view.targetPoint() )
     {
-        int tx = vconf.getScreenX( view.targetPoint()->x * reverse );
-        int ty = vconf.getScreenY( view.targetPoint()->y * reverse );
+        int tx = vconf.screenX( view.targetPoint()->x * reverse );
+        int ty = vconf.screenY( view.targetPoint()->y * reverse );
 
         painter.setPen( dconf.debugTargetPen() );
         painter.setBrush( dconf.transparentBrush() );
@@ -277,8 +277,8 @@ DebugPainter::drawBall( QPainter & painter,
                          (double)ball->vy_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
 
     const double ball_decay = rcsc::ServerParam::i().ballDecay();
-    const int ix = vconf.getScreenX( bpos.x );
-    const int iy = vconf.getScreenY( bpos.y );
+    const int ix = vconf.screenX( bpos.x );
+    const int iy = vconf.screenY( bpos.y );
     const int r = std::max( 2,
                             ( vconf.isEnlarged()
                               ? vconf.scale( 0.25 )
@@ -303,8 +303,8 @@ DebugPainter::drawBall( QPainter & painter,
         {
             bpos += bvel;
             bvel *= ball_decay;
-            bx = vconf.getScreenX( bpos.x );
-            by = vconf.getScreenY( bpos.y );
+            bx = vconf.screenX( bpos.x );
+            by = vconf.screenY( bpos.y );
             path.addEllipse( bx, by, 4, 4 );
         }
         path.moveTo( ix, iy );
@@ -352,8 +352,8 @@ DebugPainter::drawPlayers( QPainter & painter,
           it != end;
           ++it )
     {
-        const int ix = vconf.getScreenX( (double)(*it)->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
-        const int iy = vconf.getScreenY( (double)(*it)->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+        const int ix = vconf.screenX( (double)(*it)->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+        const int iy = vconf.screenY( (double)(*it)->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
 
         if ( (*it)->body_ != -360 )
         {
@@ -440,10 +440,10 @@ DebugPainter::drawLines( QPainter & painter,
           it != end;
           ++it )
     {
-        path.moveTo( vconf.getScreenX( it->x1_ * reverse ),
-                     vconf.getScreenY( it->y1_ * reverse ) );
-        path.lineTo( vconf.getScreenX( it->x2_ * reverse ),
-                     vconf.getScreenY( it->y2_ * reverse ) );
+        path.moveTo( vconf.screenX( it->x1_ * reverse ),
+                     vconf.screenY( it->y1_ * reverse ) );
+        path.lineTo( vconf.screenX( it->x2_ * reverse ),
+                     vconf.screenY( it->y2_ * reverse ) );
     }
 
     painter.drawPath( path );
@@ -478,12 +478,12 @@ DebugPainter::drawTriangles( QPainter & painter,
           it != end;
           ++it )
     {
-        int x1 = vconf.getScreenX( it->x1_ * reverse );
-        int y1 = vconf.getScreenY( it->y1_ * reverse );
-        int x2 = vconf.getScreenX( it->x2_ * reverse );
-        int y2 = vconf.getScreenY( it->y2_ * reverse );
-        int x3 = vconf.getScreenX( it->x3_ * reverse );
-        int y3 = vconf.getScreenY( it->y3_ * reverse );
+        int x1 = vconf.screenX( it->x1_ * reverse );
+        int y1 = vconf.screenY( it->y1_ * reverse );
+        int x2 = vconf.screenX( it->x2_ * reverse );
+        int y2 = vconf.screenY( it->y2_ * reverse );
+        int x3 = vconf.screenX( it->x3_ * reverse );
+        int y3 = vconf.screenY( it->y3_ * reverse );
 
         path.moveTo( x1, y1 );
         path.lineTo( x2, y2 );
@@ -522,10 +522,10 @@ DebugPainter::drawRectangles( QPainter & painter,
           it != end;
           ++it )
     {
-        int left_x = vconf.getScreenX( it->left_x_ * reverse );
-        int top_y = vconf.getScreenY( it->top_y_ * reverse );
-        int right_x = vconf.getScreenX( it->right_x_ * reverse );
-        int bottom_y = vconf.getScreenY( it->bottom_y_ * reverse );
+        int left_x = vconf.screenX( it->left_x_ * reverse );
+        int top_y = vconf.screenY( it->top_y_ * reverse );
+        int right_x = vconf.screenX( it->right_x_ * reverse );
+        int bottom_y = vconf.screenY( it->bottom_y_ * reverse );
 
         path.addRect( left_x,
                       top_y,
@@ -566,8 +566,8 @@ DebugPainter::drawCircles( QPainter & painter,
           ++it )
     {
         int r = vconf.scale( it->radius_ );
-        path.addEllipse( vconf.getScreenX( it->center_x_ * reverse ) - r,
-                         vconf.getScreenY( it->center_y_ * reverse ) - r,
+        path.addEllipse( vconf.screenX( it->center_x_ * reverse ) - r,
+                         vconf.screenY( it->center_y_ * reverse ) - r,
                          r * 2,
                          r * 2 );
     }
