@@ -348,10 +348,10 @@ FieldPainter::drawLines( QPainter & painter ) const
     painter.setBrush( dconf.transparentBrush() );
 
     // set screen coordinates of field
-    int left_x   = M_conf.getScreenX( - rcsc::ServerParam::i().pitchHalfLength() );
-    int right_x  = M_conf.getScreenX( + rcsc::ServerParam::i().pitchHalfLength() );
-    int top_y    = M_conf.getScreenY( - rcsc::ServerParam::i().pitchHalfWidth() );
-    int bottom_y = M_conf.getScreenY( + rcsc::ServerParam::i().pitchHalfWidth() );
+    int left_x   = M_conf.screenX( - rcsc::ServerParam::i().pitchHalfLength() );
+    int right_x  = M_conf.screenX( + rcsc::ServerParam::i().pitchHalfLength() );
+    int top_y    = M_conf.screenY( - rcsc::ServerParam::i().pitchHalfWidth() );
+    int bottom_y = M_conf.screenY( + rcsc::ServerParam::i().pitchHalfWidth() );
 
     // side lines & goal lines
     painter.drawLine( left_x, top_y, right_x, top_y );
@@ -363,8 +363,8 @@ FieldPainter::drawLines( QPainter & painter ) const
          || rcsc::ServerParam::i().keepawayMode() )
     {
         // keepaway area
-        int ka_left = M_conf.getScreenX( - rcsc::ServerParam::i().keepawayLength() * 0.5 );
-        int ka_top = M_conf.getScreenY( - rcsc::ServerParam::i().keepawayWidth() * 0.5 );
+        int ka_left = M_conf.screenX( - rcsc::ServerParam::i().keepawayLength() * 0.5 );
+        int ka_top = M_conf.screenY( - rcsc::ServerParam::i().keepawayWidth() * 0.5 );
         int ka_width = M_conf.scale( rcsc::ServerParam::i().keepawayWidth() );
         int ka_length = M_conf.scale( rcsc::ServerParam::i().keepawayWidth() );
 
@@ -398,12 +398,12 @@ FieldPainter::drawPenaltyAreaLines( QPainter & painter ) const
     painter.setBrush( dconf.transparentBrush() );
 
     // set screen coordinates of field
-    int left_x   = M_conf.getScreenX( - rcsc::ServerParam::i().pitchHalfLength() );
-    int right_x  = M_conf.getScreenX( + rcsc::ServerParam::i().pitchHalfLength() );
+    int left_x   = M_conf.screenX( - rcsc::ServerParam::i().pitchHalfLength() );
+    int right_x  = M_conf.screenX( + rcsc::ServerParam::i().pitchHalfLength() );
 
     // set penalty area params
-    int pen_top_y    = M_conf.getScreenY( - rcsc::ServerParam::i().penaltyAreaHalfWidth() );
-    int pen_bottom_y = M_conf.getScreenY( + rcsc::ServerParam::i().penaltyAreaHalfWidth() );
+    int pen_top_y    = M_conf.screenY( - rcsc::ServerParam::i().penaltyAreaHalfWidth() );
+    int pen_bottom_y = M_conf.screenY( + rcsc::ServerParam::i().penaltyAreaHalfWidth() );
     double pen_circle_y_degree_abs
         = std::acos( ( rcsc::ServerParam::i().penaltyAreaLength()
                        - rcsc::ServerParam::DEFAULT_PENALTY_SPOT_DIST )
@@ -414,11 +414,11 @@ FieldPainter::drawPenaltyAreaLines( QPainter & painter ) const
     int pen_circle_size = M_conf.scale( rcsc::ServerParam::DEFAULT_PENALTY_CIRCLE_R * 2.0 );
 
     // left penalty area X
-    int pen_x = M_conf.getScreenX( -( rcsc::ServerParam::i().pitchHalfLength()
-                                      - rcsc::ServerParam::i().penaltyAreaLength() ) );
+    int pen_x = M_conf.screenX( -( rcsc::ServerParam::i().pitchHalfLength()
+                                   - rcsc::ServerParam::i().penaltyAreaLength() ) );
     // left arc
-    int pen_spot_x = M_conf.getScreenX( -( rcsc::ServerParam::i().pitchHalfLength()
-                                           - rcsc::ServerParam::DEFAULT_PENALTY_SPOT_DIST ) );
+    int pen_spot_x = M_conf.screenX( -( rcsc::ServerParam::i().pitchHalfLength()
+                                        - rcsc::ServerParam::DEFAULT_PENALTY_SPOT_DIST ) );
     painter.drawArc( pen_spot_x - pen_circle_r + 1,
                      M_conf.fieldCenter().y - pen_circle_r,
                      pen_circle_size,
@@ -433,11 +433,11 @@ FieldPainter::drawPenaltyAreaLines( QPainter & painter ) const
     painter.drawPoint( pen_spot_x, M_conf.fieldCenter().y );
 
     // right penalty area X
-    pen_x = M_conf.getScreenX( +( rcsc::ServerParam::i().pitchHalfLength()
-                                  - rcsc::ServerParam::i().penaltyAreaLength() ) );
+    pen_x = M_conf.screenX( +( rcsc::ServerParam::i().pitchHalfLength()
+                               - rcsc::ServerParam::i().penaltyAreaLength() ) );
     // right arc
-    pen_spot_x = M_conf.getScreenX( +( rcsc::ServerParam::i().pitchHalfLength()
-                                       - rcsc::ServerParam::DEFAULT_PENALTY_SPOT_DIST ) );
+    pen_spot_x = M_conf.screenX( +( rcsc::ServerParam::i().pitchHalfLength()
+                                    - rcsc::ServerParam::DEFAULT_PENALTY_SPOT_DIST ) );
     painter.drawArc( pen_spot_x - pen_circle_r,
                      M_conf.fieldCenter().y - pen_circle_r,
                      pen_circle_size, pen_circle_size,
@@ -464,8 +464,8 @@ FieldPainter::drawGoalAreaLines( QPainter & painter ) const
     painter.setBrush( dconf.transparentBrush() );
 
     // set screen coordinates of field
-    int left_x   = M_conf.getScreenX( - rcsc::ServerParam::i().pitchHalfLength() );
-    int right_x  = M_conf.getScreenX( + rcsc::ServerParam::i().pitchHalfLength() );
+    int left_x   = M_conf.screenX( - rcsc::ServerParam::i().pitchHalfLength() );
+    int right_x  = M_conf.screenX( + rcsc::ServerParam::i().pitchHalfLength() );
 
     // set coordinates M_confs
     int goal_area_y_abs = M_conf.scale( rcsc::ServerParam::i().goalAreaHalfWidth() );
@@ -473,15 +473,15 @@ FieldPainter::drawGoalAreaLines( QPainter & painter ) const
     int goal_area_bottom_y = M_conf.fieldCenter().y + goal_area_y_abs;
 
     // left goal area
-    int goal_area_x = M_conf.getScreenX( - rcsc::ServerParam::i().pitchHalfLength()
-                                         + rcsc::ServerParam::i().goalAreaLength() );
+    int goal_area_x = M_conf.screenX( - rcsc::ServerParam::i().pitchHalfLength()
+                                      + rcsc::ServerParam::i().goalAreaLength() );
     painter.drawLine( left_x, goal_area_top_y, goal_area_x, goal_area_top_y );
     painter.drawLine( goal_area_x, goal_area_top_y, goal_area_x, goal_area_bottom_y );
     painter.drawLine( goal_area_x, goal_area_bottom_y, left_x, goal_area_bottom_y );
 
     // right goal area
-    goal_area_x = M_conf.getScreenX( rcsc::ServerParam::i().pitchHalfLength()
-                                     - rcsc::ServerParam::i().goalAreaLength() );
+    goal_area_x = M_conf.screenX( rcsc::ServerParam::i().pitchHalfLength()
+                                  - rcsc::ServerParam::i().goalAreaLength() );
     painter.drawLine( right_x, goal_area_top_y, goal_area_x, goal_area_top_y );
     painter.drawLine( goal_area_x, goal_area_top_y, goal_area_x, goal_area_bottom_y );
     painter.drawLine( goal_area_x, goal_area_bottom_y, right_x, goal_area_bottom_y );
@@ -499,24 +499,24 @@ FieldPainter::drawGoals( QPainter & painter ) const
     painter.setBrush( Qt::black );
 
     // set coordinates param
-    int goal_top_y = M_conf.getScreenY( - rcsc::ServerParam::i().goalHalfWidth() );
+    int goal_top_y = M_conf.screenY( - rcsc::ServerParam::i().goalHalfWidth() );
     int goal_size_x = M_conf.scale( rcsc::ServerParam::i().goalDepth() );
     int goal_size_y = M_conf.scale( rcsc::ServerParam::i().goalWidth() );
 
-    int post_top_y = M_conf.getScreenY( - rcsc::ServerParam::i().goalHalfWidth()
-                                        - rcsc::ServerParam::i().goalPostRadius() * 2.0 );
-    int post_bottom_y = M_conf.getScreenY( + rcsc::ServerParam::i().goalHalfWidth() );
+    int post_top_y = M_conf.screenY( - rcsc::ServerParam::i().goalHalfWidth()
+                                     - rcsc::ServerParam::i().goalPostRadius() * 2.0 );
+    int post_bottom_y = M_conf.screenY( + rcsc::ServerParam::i().goalHalfWidth() );
     int post_diameter = M_conf.scale( rcsc::ServerParam::i().goalPostRadius() * 2.0 );
 
     // left goal
-    painter.drawRect( M_conf.getScreenX( - rcsc::ServerParam::i().pitchHalfLength()
-                                         - rcsc::ServerParam::i().goalDepth() ) - 1,
+    painter.drawRect( M_conf.screenX( - rcsc::ServerParam::i().pitchHalfLength()
+                                      - rcsc::ServerParam::i().goalDepth() ) - 1,
                       goal_top_y,
                       goal_size_x,
                       goal_size_y );
     if ( post_diameter >= 1 )
     {
-        int post_x = M_conf.getScreenX( - rcsc::ServerParam::i().pitchHalfLength() );
+        int post_x = M_conf.screenX( - rcsc::ServerParam::i().pitchHalfLength() );
         painter.drawEllipse( post_x,
                              post_top_y,
                              post_diameter,
@@ -527,14 +527,14 @@ FieldPainter::drawGoals( QPainter & painter ) const
                              post_diameter );
     }
     // right goal
-    painter.drawRect( M_conf.getScreenX( rcsc::ServerParam::i().pitchHalfLength() ) + 1,
+    painter.drawRect( M_conf.screenX( rcsc::ServerParam::i().pitchHalfLength() ) + 1,
                       goal_top_y,
                       goal_size_x,
                       goal_size_y );
     if ( post_diameter >= 1 )
     {
-        int post_x = M_conf.getScreenX( rcsc::ServerParam::i().pitchHalfLength()
-                                        - rcsc::ServerParam::i().goalPostRadius() * 2.0 );
+        int post_x = M_conf.screenX( rcsc::ServerParam::i().pitchHalfLength()
+                                     - rcsc::ServerParam::i().goalPostRadius() * 2.0 );
         painter.drawEllipse( post_x,
                              post_top_y,
                              post_diameter,
