@@ -134,6 +134,10 @@ MainWindow::MainWindow()
         this->showFullScreen();
     }
 
+//     if ( AppConfig::instance().hideMenuBar() )
+//     {
+//         this->menuBar()->hide();
+//     }
 }
 
 /*-------------------------------------------------------------------*/
@@ -356,6 +360,12 @@ MainWindow::createActionsMonitor()
 void
 MainWindow::createActionsView()
 {
+    //     M_toggle_menu_bar_act = new QAction( tr( "&Menu Bar" ), this );
+    //     M_toggle_menu_bar_act->setShortcut( tr( "Ctrl+M" ) );
+    //     M_toggle_menu_bar_act->setStatusTip( tr( "Show/Hide Menu Bar" ) );
+    //     connect( M_toggle_menu_bar_act, SIGNAL( triggered() ),
+    //              this, SLOT( toggleMenuBar() ) );
+
     M_toggle_tool_bar_act = new QAction( tr( "&Tool Bar" ), this );
     M_toggle_tool_bar_act->setStatusTip( tr( "Show/Hide Tool Bar" ) );
     connect( M_toggle_tool_bar_act, SIGNAL( triggered() ),
@@ -523,6 +533,7 @@ void
 MainWindow::createMenuView()
 {
     QMenu * menu = menuBar()->addMenu( tr( "&View" ) );
+    //    menu->addAction( M_toggle_menu_bar_act );
     menu->addAction( M_toggle_tool_bar_act );
     menu->addAction( M_toggle_status_bar_act );
     menu->addSeparator();
@@ -1544,6 +1555,16 @@ MainWindow::restartServer()
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+MainWindow::toggleMenuBar()
+{
+    this->menuBar()->setVisible( ! this->menuBar()->isVisible() );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 MainWindow::toggleToolBar()
@@ -1887,8 +1908,8 @@ MainWindow::updatePositionLabel( const QPoint & point )
          && statusBar()->isVisible()
          )
     {
-        double x = M_main_data.viewConfig().getFieldX( point.x() );
-        double y = M_main_data.viewConfig().getFieldY( point.y() );
+        double x = M_main_data.viewConfig().fieldX( point.x() );
+        double y = M_main_data.viewConfig().fieldY( point.y() );
 
         char buf[32];
         std::snprintf( buf, 32,
@@ -1930,8 +1951,8 @@ MainWindow::dropBall( const QPoint & point )
     if ( M_monitor_client
          && M_monitor_client->isConnected() )
     {
-        double x = M_main_data.viewConfig().getFieldX( point.x() );
-        double y = M_main_data.viewConfig().getFieldY( point.y() );
+        double x = M_main_data.viewConfig().fieldX( point.x() );
+        double y = M_main_data.viewConfig().fieldY( point.y() );
 
         std::cerr << "drop ball to ("
                   << x << ", " << y << ")"
@@ -1950,8 +1971,8 @@ MainWindow::freeKickLeft( const QPoint & point )
     if ( M_monitor_client
          && M_monitor_client->isConnected() )
     {
-        double x = M_main_data.viewConfig().getFieldX( point.x() );
-        double y = M_main_data.viewConfig().getFieldY( point.y() );
+        double x = M_main_data.viewConfig().fieldX( point.x() );
+        double y = M_main_data.viewConfig().fieldY( point.y() );
 
         std::cerr << "free kick left at ("
                   << x << ", " << y << ")"
@@ -1970,8 +1991,8 @@ MainWindow::freeKickRight( const QPoint & point )
     if ( M_monitor_client
          && M_monitor_client->isConnected() )
     {
-        double x = M_main_data.viewConfig().getFieldX( point.x() );
-        double y = M_main_data.viewConfig().getFieldY( point.y() );
+        double x = M_main_data.viewConfig().fieldX( point.x() );
+        double y = M_main_data.viewConfig().fieldY( point.y() );
 
         std::cerr << "free kick right at ("
                   << x << ", " << y << ")"
