@@ -58,8 +58,8 @@ PlayerPainter::Param::Param( const Player & player,
                              const Ball & ball,
                              const ViewConfig & view_conf,
                              const rcsc::PlayerType & ptype )
-    : x_( view_conf.getScreenX( player.x() ) )
-    , y_( view_conf.getScreenY( player.y() ) )
+    : x_( view_conf.screenX( player.x() ) )
+    , y_( view_conf.screenY( player.y() ) )
     , body_radius_( view_conf.scale( ptype.playerSize() ) )
     , kick_radius_( view_conf.scale( ptype.kickableArea() ) )
     , have_full_effort_( player.hasFullEffort( ptype.effortMax() ) )
@@ -636,8 +636,8 @@ PlayerPainter::drawFuture( QPainter & painter,
 
     const int last = M_main_data.viewConfig().playerFutureCycle();
 
-    QPoint first_point( M_main_data.viewConfig().getScreenX( ppos.x ),
-                        M_main_data.viewConfig().getScreenY( ppos.y ) ) ;
+    QPoint first_point( M_main_data.viewConfig().screenX( ppos.x ),
+                        M_main_data.viewConfig().screenY( ppos.y ) ) ;
     QPoint last_point = first_point;
 
     // draw kickable area edge
@@ -658,8 +658,8 @@ PlayerPainter::drawFuture( QPainter & painter,
         ppos += pvel;
         pvel *= param.player_type_.playerDecay();
 
-        QPoint pt( M_main_data.viewConfig().getScreenX( ppos.x ),
-                   M_main_data.viewConfig().getScreenY( ppos.y ) );
+        QPoint pt( M_main_data.viewConfig().screenX( ppos.x ),
+                   M_main_data.viewConfig().screenY( ppos.y ) );
         if ( std::abs( last_point.x() - pt.x() ) < 1
              && std::abs( last_point.y() - pt.y() ) < 1 )
         {
@@ -836,14 +836,14 @@ PlayerPainter::drawControlArea( QPainter & painter,
         double right_y = rcsc::ServerParam::i().tackleWidth() * body_angle_side.sin();
 
         QPoint pts[4];
-        pts[0].setX( vconf.getScreenX( ppos.x + forward_x + right_x ) );
-        pts[0].setY( vconf.getScreenY( ppos.y + forward_y + right_y ) );
-        pts[1].setX( vconf.getScreenX( ppos.x + forward_x - right_x ) );
-        pts[1].setY( vconf.getScreenY( ppos.y + forward_y - right_y ) );
-        pts[2].setX( vconf.getScreenX( ppos.x + back_x - right_x ) );
-        pts[2].setY( vconf.getScreenY( ppos.y + back_y - right_y ) );
-        pts[3].setX( vconf.getScreenX( ppos.x + back_x + right_x ) );
-        pts[3].setY( vconf.getScreenY( ppos.y + back_y + right_y ) );
+        pts[0].setX( vconf.screenX( ppos.x + forward_x + right_x ) );
+        pts[0].setY( vconf.screenY( ppos.y + forward_y + right_y ) );
+        pts[1].setX( vconf.screenX( ppos.x + forward_x - right_x ) );
+        pts[1].setY( vconf.screenY( ppos.y + forward_y - right_y ) );
+        pts[2].setX( vconf.screenX( ppos.x + back_x - right_x ) );
+        pts[2].setY( vconf.screenY( ppos.y + back_y - right_y ) );
+        pts[3].setX( vconf.screenX( ppos.x + back_x + right_x ) );
+        pts[3].setY( vconf.screenY( ppos.y + back_y + right_y ) );
 
         painter.setPen( dconf.tackleAreaPen() );
         painter.setBrush( dconf.transparentBrush() );
