@@ -647,16 +647,6 @@ ColorSettingDialog::createColorButtons()
         layout->addWidget( btn, row, col, Qt::AlignLeft );
     }
     ++row;
-    {
-        QString name = tr( "Debug Figure" );
-        ColorButton * btn = new ColorButton( name,
-                                             DrawConfig::instance().debugFigurePenPtr(),
-                                             NULL,
-                                             this );
-        M_color_buttons.insert( std::pair< QString, ColorButton * >( name, btn ) );
-        layout->addWidget( btn, row, col, Qt::AlignLeft );
-    }
-    ++row;
     {
         QString name = tr( "Debug Comment" );
         ColorButton * btn = new ColorButton( name,
@@ -677,6 +667,26 @@ ColorSettingDialog::createColorButtons()
         layout->addWidget( btn, row, col, Qt::AlignLeft );
     }
     ++row;
+    {
+        QString name = tr( "Debug Log Font" );
+        ColorButton * btn = new ColorButton( name,
+                                             DrawConfig::instance().debugLogMessageFontPenPtr(),
+                                             NULL,
+                                             this );
+        M_color_buttons.insert( std::pair< QString, ColorButton * >( name, btn ) );
+        layout->addWidget( btn, row, col, Qt::AlignLeft );
+    }
+    ++row;
+    {
+        QString name = tr( "Debug Figure" );
+        ColorButton * btn = new ColorButton( name,
+                                             DrawConfig::instance().debugFigurePenPtr(),
+                                             NULL,
+                                             this );
+        M_color_buttons.insert( std::pair< QString, ColorButton * >( name, btn ) );
+        layout->addWidget( btn, row, col, Qt::AlignLeft );
+    }
+    ++row;
 
     return layout;
 }
