@@ -56,6 +56,8 @@
 #include "xpm/debug_view_target.xpm"
 #include "xpm/debug_view_message.xpm"
 
+#include "xpm/debug_log_view.xpm"
+
 #include "xpm/open_dir.xpm"
 
 #include "xpm/sync.xpm"
@@ -87,12 +89,27 @@ DebugMessageWindow::DebugMessageWindow( QWidget * parent,
                                         MainData & main_data )
     : QMainWindow( parent )
     , M_main_data( main_data )
-    , M_debug_holder( new DebugLogHolder )
-    , M_level( 0xFFFF )
 {
     //this->setWindowTitle( tr( "Debug Message" ) ); // qt4
     this->setCaption( tr( "Debug Message" ) ); // qt3
 
+    M_debug_text[0] = tr( "System" );
+    M_debug_text[1] = tr( "Sensor" );
+    M_debug_text[2] = tr( "WorldModel" );
+    M_debug_text[3] = tr( "BasicAction" );
+    M_debug_text[4] = tr( "Intercept" );
+    M_debug_text[5] = tr( "Kick" );
+    M_debug_text[6] = tr( "Dribble" );
+    M_debug_text[7] = tr( "Pass" );
+    M_debug_text[8] = tr( "Cross" );
+    M_debug_text[9] = tr( "Shoot" );
+    M_debug_text[10] = tr( "Clear" );
+    M_debug_text[11] = tr( "Team" );
+    M_debug_text[12] = tr( "Role" );
+    //M_debug_text[13] = tr( "" );
+    //M_debug_text[14] = tr( "" );
+    //M_debug_text[15] = tr( "" );
+
     createActions();
     createWindows();
 
@@ -124,10 +141,11 @@ DebugMessageWindow::loadSettings()
 
     settings.beginGroup( "/.soccerwindow2-qt3./DebugMessageWindow" );
 
+    // read debug switch status
     for ( int i = 0; i < 16; ++i )
     {
-        char key[16];
-        std::snprintf( key, 16, "debug%02d", i + 1 );
+        char key[32];
+        std::snprintf( key, 32, "debug%02d", i + 1 );
 
         //QVariant val = settings.value( QString::fromAscii( key ) );
         bool ok = false;
@@ -136,19 +154,30 @@ DebugMessageWindow::loadSettings()
                                               &ok );
         if ( ok )
         {
-            int level = DebugLogData::LEVEL_1 << i;
-            if ( enable )
-            {
-                M_level |= level;
-            }
-            else
-            {
-                M_level &= ~level;
-            }
+            boost::int32_t level = DebugLogData::LEVEL_01 << i;
+            M_main_data.getDebugLogHolder().setLevel( level, enable );
 
             M_debug_level_act[i]->setOn( enable );
         }
+    }
 
+    // read debug text string
+    for ( int i = 0; i < 16; ++i )
+    {
+        char key[32];
+        std::snprintf( key, 32, "debug_text_%02d", i + 1 );
+
+        bool ok = false;
+        QString val = settings.readEntry( QString::fromAscii( key ),
+                                          QString::null,
+                                          &ok );
+        if ( ok )
+        {
+            M_debug_text[i] = val;
+            QString text = tr( "Level %1 " ).arg( i + 1 ) + val;
+            M_debug_level_act[i]->setText( text );
+            M_debug_level_act[i]->setStatusTip( tr( "Debug " ) + text );
+        }
     }
 
     settings.endGroup();
@@ -169,13 +198,23 @@ DebugMessageWindow::saveSettings()
 
     for ( int i = 0; i < 16; ++i )
     {
-        char key[16];
-        std::snprintf( key, 16, "debug%02d", i + 1 );
+        char key[32];
+        std::snprintf( key, 32, "debug%02d", i + 1 );
 
         settings.writeEntry( QString::fromAscii( key ),
                              M_debug_level_act[i]->isOn() );
     }
 
+    for ( int i = 0; i < 16; ++i )
+    {
+        if ( ! M_debug_text[i].isEmpty() )
+        {
+            char key[32];
+            std::snprintf( key, 16, "debug_text_%02d", i + 1 );
+            settings.writeEntry( QString::fromAscii( key ), M_debug_text[i] );
+        }
+    }
+
     settings.endGroup();
 }
 
@@ -276,6 +315,19 @@ DebugMessageWindow::createActions()
     connect( M_show_debug_view_message_act, SIGNAL( toggled( bool ) ),
              this, SLOT( toggleShowDebugViewMessage( bool ) ) );
 
+    //////////////////////////////////////////////
+    // debug log view
+    M_show_debug_log_view_act
+        = new QAction( QIconSet( QPixmap( debug_log_view_xpm ) ),
+                       tr( "Toggle debug log view" ),
+                       QKeySequence(),
+                       this );
+    M_show_debug_log_view_act->setStatusTip( tr( "Show/Hide debug log view" ) );
+    M_show_debug_log_view_act->setToggleAction( true );
+    M_show_debug_log_view_act->setOn( true );
+    connect( M_show_debug_log_view_act, SIGNAL( toggled( bool ) ),
+             this, SLOT( toggleShowDebugLogView( bool ) ) );
+
     //////////////////////////////////////////////
     // dir selection
     M_open_debug_log_dir_act
@@ -318,169 +370,30 @@ DebugMessageWindow::createActions()
 
     //////////////////////////////////////////////
     // debug level switches
-    int i = 0;
 
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_1_xpm ) ),
-                                        tr( "Level 1 System" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 1 System" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_1( bool ) ) );
-    ++i;
+    char ** num_xpm[16] = { num_1_xpm, num_2_xpm, num_3_xpm, num_4_xpm,
+                            num_5_xpm, num_6_xpm, num_7_xpm, num_8_xpm,
+                            num_9_xpm, num_10_xpm, num_11_xpm, num_12_xpm,
+                            num_13_xpm, num_14_xpm, num_15_xpm, num_16_xpm };
 
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_2_xpm ) ),
-                                        tr( "Level 2 Sensor" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 2 Sensor" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_2( bool ) ) );
-    ++i;
+    QSignalMapper * debug_level_mapper = new QSignalMapper( this );
+    connect( debug_level_mapper, SIGNAL( mapped( int ) ),
+             this, SLOT( toggleDebugLevel( int ) ) );
 
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_3_xpm ) ),
-                                        tr( "Level 3 WorldModel" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 3 WorldModel" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_3( bool ) ) );
-    ++i;
+    for ( int i = 0; i < 16; ++i )
+    {
+        QString menu_text = tr( "Level %1 " ).arg( i + 1 ) + M_debug_text[i];
+        M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_xpm[i] ) ),
+                                            menu_text,
+                                            QKeySequence(),
+                                            this ); //M_debug_level_act_group );
+        M_debug_level_act[i]->setStatusTip( tr( "Debug " ) + menu_text );
+        M_debug_level_act[i]->setToggleAction( true );
 
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_4_xpm ) ),
-                                        tr( "Level 4 BasicAction" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 4 BasicAction" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_4( bool ) ) );
-    ++i;
-
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_5_xpm ) ),
-                                        tr( "Level 5 Intercept" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 5 Intercept" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_5( bool ) ) );
-    ++i;
-
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_6_xpm ) ),
-                                        tr( "Level 6 Kick" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 6 Kick" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_6( bool ) ) );
-    ++i;
-
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_7_xpm ) ),
-                                        tr( "Level 7 Dribble" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 7 Dribble" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_7( bool ) ) );
-    ++i;
-
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_8_xpm ) ),
-                                        tr( "Level 8 Pass" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 8 Pass" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_8( bool ) ) );
-    ++i;
-
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_9_xpm ) ),
-                                        tr( "Level 9 Cross" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 9 Cross" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_9( bool ) ) );
-    ++i;
-
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_10_xpm ) ),
-                                        tr( "Level 10 Shoot" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 10 Shoot" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_10( bool ) ) );
-    ++i;
-
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_11_xpm ) ),
-                                        tr( "Level 11 Clear" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 11 Clear" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_11( bool ) ) );
-    ++i;
-
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_12_xpm ) ),
-                                        tr( "Level 12 Team" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 12 Team" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_12( bool ) ) );
-    ++i;
-
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_13_xpm ) ),
-                                        tr( "Level 13 Role" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 13 Role" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_13( bool ) ) );
-    ++i;
-
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_14_xpm ) ),
-                                        tr( "Level 14" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 14" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_14( bool ) ) );
-    ++i;
-
-
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_15_xpm ) ),
-                                        tr( "Level 15" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 15" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_15( bool ) ) );
-    ++i;
-
-
-    M_debug_level_act[i] = new QAction( QIconSet( QPixmap( num_16_xpm ) ),
-                                        tr( "Level 16" ),
-                                        QKeySequence(),
-                                        this );
-    M_debug_level_act[i]->setStatusTip( tr( "Debug Level 16" ) );
-    M_debug_level_act[i]->setToggleAction( true );
-    connect( M_debug_level_act[i], SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleDebugLevel_16( bool ) ) );
-    ++i;
+        connect( M_debug_level_act[i], SIGNAL( activated() ),
+                 debug_level_mapper, SLOT( map() ) );
+        debug_level_mapper->setMapping( M_debug_level_act[i], i + 1 );
+    }
 }
 
 
@@ -568,10 +481,12 @@ DebugMessageWindow::createToolBar()
 
         tbar->addSeparator();
 
-        for ( int i = 0; i < 16; ++i )
-        {
-            M_debug_level_act[i]->addTo( tbar );
-        }
+        M_show_debug_log_view_act->addTo( tbar );
+
+         for ( int i = 0; i < 16; ++i )
+         {
+             M_debug_level_act[i]->addTo( tbar );
+         }
 
         this->addDockWindow( tbar, Qt::DockBottom );
     }
@@ -599,20 +514,24 @@ DebugMessageWindow::loadDebugLogDir( const rcsc::SideID side,
         return;
     }
 
+    const int unum = M_tab_widget->currentPageIndex() + 1;
+
     if ( side == rcsc::LEFT )
     {
-        if ( M_debug_holder->setDir( ptr->leftTeam().name(),
-                                     M_tab_widget->currentPageIndex() + 1,
-                                     dir_path ) )
+        if ( M_main_data.getDebugLogHolder().setDir( ptr->leftTeam().name(),
+                                                     side,
+                                                     unum,
+                                                     dir_path ) )
         {
             syncCycle();
         }
     }
     else if ( side == rcsc::RIGHT )
     {
-        if ( M_debug_holder->setDir( ptr->rightTeam().name(),
-                                     M_tab_widget->currentPageIndex() + 1,
-                                     dir_path ) )
+        if ( M_main_data.getDebugLogHolder().setDir( ptr->rightTeam().name(),
+                                                     side,
+                                                     unum,
+                                                     dir_path ) )
         {
             syncCycle();
         }
@@ -747,6 +666,20 @@ DebugMessageWindow::toggleShowDebugViewMessage( bool checked )
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+DebugMessageWindow::toggleShowDebugLogView( bool checked )
+{
+    if ( M_main_data.viewConfig().isShownDebugLogView() != checked )
+    {
+        M_main_data.getViewConfig().toggleShowDebugLogView();
+        emit configured();
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 DebugMessageWindow::showDebugLogDirDialog()
@@ -789,7 +722,7 @@ DebugMessageWindow::syncCycle()
 
     //std::cerr << "sync debug data cycle" << std::endl;
     // seek current cycle data
-    if ( ! M_debug_holder->seekData( M_tab_widget->currentPageIndex() + 1,
+    if ( ! M_main_data.getDebugLogHolder().seekData( M_tab_widget->currentPageIndex() + 1,
                                      ptr->cycle() ) )
     {
         std::cerr << "No data! number = "
@@ -808,7 +741,7 @@ DebugMessageWindow::syncCycle()
 void
 DebugMessageWindow::decrementCycle()
 {
-    if ( ! M_debug_holder->decDataCycle( M_tab_widget->currentPageIndex() + 1 ) )
+    if ( ! M_main_data.getDebugLogHolder().decDataCycle( M_tab_widget->currentPageIndex() + 1 ) )
     {
         return;
     }
@@ -823,7 +756,7 @@ DebugMessageWindow::decrementCycle()
 void
 DebugMessageWindow::incrementCycle()
 {
-    if ( ! M_debug_holder->incDataCycle( M_tab_widget->currentPageIndex() + 1 ) )
+    if ( ! M_main_data.getDebugLogHolder().incDataCycle( M_tab_widget->currentPageIndex() + 1 ) )
     {
         //std::cerr << "Failed increment debug log" << std::endl;
         return;
@@ -865,318 +798,20 @@ DebugMessageWindow::findString( const QString & expr )
 
 */
 void
-DebugMessageWindow::toggleDebugLevel_1( bool checked )
+DebugMessageWindow::toggleDebugLevel( int level )
 {
     //M_level ^= DebugLogData::LEVEL_1; // reverse only 1 bit
 
-    if ( checked )
+    if ( level < 1 || 16 < level )
     {
-        M_level |= DebugLogData::LEVEL_1;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_1;
+        std::cerr << "Invalid level value " << level << std::endl;
+        return;
     }
 
-    updateMessage();
-    emit configured();
-}
+    int level_flag = 1 << ( level - 1 );
 
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_2( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_2;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_2;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_3( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_3;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_3;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_4( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_4;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_4;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_5( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_5;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_5;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_6( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_6;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_6;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_7( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_7;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_7;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_8( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_8;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_8;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_9( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_9;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_9;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_10( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_10;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_10;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_11( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_11;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_11;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_12( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_12;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_12;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_13( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_13;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_13;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_14( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_14;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_14;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_15( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_15;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_15;
-    }
-
-    updateMessage();
-    emit configured();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-DebugMessageWindow::toggleDebugLevel_16( bool checked )
-{
-    if ( checked )
-    {
-        M_level |= DebugLogData::LEVEL_16;
-    }
-    else
-    {
-        M_level &= ~DebugLogData::LEVEL_16;
-    }
+    M_main_data.getDebugLogHolder().setLevel( level_flag,
+                                              M_debug_level_act[level-1]->isOn() );
 
     updateMessage();
     emit configured();
@@ -1189,7 +824,7 @@ DebugMessageWindow::toggleDebugLevel_16( bool checked )
 void
 DebugMessageWindow::clearAll()
 {
-    M_debug_holder = boost::shared_ptr< DebugLogHolder >( new DebugLogHolder );
+    M_main_data.getDebugLogHolder().clear();
 
     for ( int i = 0; i < 11; ++i )
     {
@@ -1207,20 +842,21 @@ DebugMessageWindow::updateMessage()
     //std::cerr << "DebuMessageWindow::updateMessage()" << std::endl;
 
     const DebugLogHolder::DataList * data_list
-        = M_debug_holder->getDataList( M_tab_widget->currentPageIndex() + 1 );
+        = M_main_data.getDebugLogHolder().getDataList( M_tab_widget->currentPageIndex() + 1 );
     if ( ! data_list )
     {
         std::cerr << "DebuMessageWindow::updateMessage() no data list" << std::endl;
         return;
     }
 
-    if ( M_level == 0 )
+    const boost::int32_t level = M_main_data.getDebugLogHolder().level();
+    if ( level == 0 )
     {
         std::cerr << "DebuMessageWindow::updateMessage() no debug level" << std::endl;
         return;
     }
 
-    const long cur_cycle = M_debug_holder->getCurrentCycle();
+    const long cur_cycle = M_main_data.getDebugLogHolder().getCurrentCycle();
 
     QTextEdit * text_edit = M_message[ M_tab_widget->currentPageIndex() ];
 
@@ -1256,16 +892,17 @@ DebugMessageWindow::updateMessage()
         cycle_line += tr( " ------------------------------\n" );
         text_edit->append( cycle_line );
 
-        const DebugLogData::TextList::const_iterator text_end = (*data_it)->textList().end();
-        for ( DebugLogData::TextList::const_iterator text_it = (*data_it)->textList().begin();
+        const DebugLogData::TextCont::const_iterator text_end = (*data_it)->textCont().end();
+        for ( DebugLogData::TextCont::const_iterator text_it = (*data_it)->textCont().begin();
               text_it != text_end;
               ++text_it )
         {
             // level check
-            if ( M_level & text_it->first )
+            if ( level & text_it->level_ )
             {
-                //main_buffer += QString::fromStdString( text_it->second );
-                main_buffer += QString::fromAscii( text_it->second.c_str() );
+                //main_buffer += QString::fromStdString( text_it->msg_ );
+                //main_buffer += QString::fromAscii( text_it->msg_.c_str() );
+                main_buffer += text_it->msg_;
                 if ( ++n_line > 1000 )
                 {
                     // append message to text control
