@@ -38,8 +38,8 @@
 #include "debug_painter.h"
 
 #include "draw_config.h"
-// model
 #include "main_data.h"
+#include "debug_view_data.h"
 
 #include <rcsc/common/server_param.h>
 
@@ -190,9 +190,14 @@ DebugPainter::drawSelf( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( player_side == rcsc::RIGHT ? -1.0 : 1.0 );
-    const int ix = vconf.getScreenX( (double)self->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
-    const int iy = vconf.getScreenY( (double)self->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+    const double reverse = ( vconf.reverseValue()
+                             * ( player_side == rcsc::LEFT
+                                 ? 1.0
+                                 : -1.0 )
+                             );
+
+    const int ix = vconf.screenX( (double)self->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+    const int iy = vconf.screenY( (double)self->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
     const int r = std::max( 2,
                             ( vconf.isEnlarged()
                               ? vconf.scale( 1.0 )
@@ -202,8 +207,8 @@ DebugPainter::drawSelf( QPainter & painter,
     if ( vconf.isShownDebugViewTarget()
          &&  view.targetPoint() )
     {
-        int tx = vconf.getScreenX( view.targetPoint()->x * reverse );
-        int ty = vconf.getScreenY( view.targetPoint()->y * reverse );
+        int tx = vconf.screenX( view.targetPoint()->x * reverse );
+        int ty = vconf.screenY( view.targetPoint()->y * reverse );
 
         painter.setPen( dconf.debugTargetPen() );
         painter.setBrush( dconf.transparentBrush() );
@@ -216,6 +221,7 @@ DebugPainter::drawSelf( QPainter & painter,
 
     // draw body half circle
     double body_start_dir = - ( (double)self->body_ + 90.0 );
+    if ( vconf.reverseSide() ) body_start_dir += 180.0;
     if ( player_side == rcsc::RIGHT ) body_start_dir -= 180.0;
 
     painter.setPen( dconf.transparentPen() );
@@ -247,7 +253,8 @@ DebugPainter::drawSelf( QPainter & painter,
 
         painter.drawText( ix - r,
                           iy + r + painter.fontMetrics().ascent(),
-                          QString::fromAscii( self->comment_.c_str() ) );
+                          self->comment_ );
+                          //QString::fromAscii( self->comment_.c_str() ) );
     }
 }
 
@@ -270,15 +277,20 @@ DebugPainter::drawBall( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( player_side == rcsc::RIGHT ? -1.0 : 1.0 );
+    const double reverse = ( vconf.reverseValue()
+                             * ( player_side == rcsc::LEFT
+                                 ? 1.0
+                                 : -1.0 )
+                             );
+
     rcsc::Vector2D bpos( (double)ball->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse,
                          (double)ball->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
     rcsc::Vector2D bvel( (double)ball->vx_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse,
                          (double)ball->vy_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
 
     const double ball_decay = rcsc::ServerParam::i().ballDecay();
-    const int ix = vconf.getScreenX( bpos.x );
-    const int iy = vconf.getScreenY( bpos.y );
+    const int ix = vconf.screenX( bpos.x );
+    const int iy = vconf.screenY( bpos.y );
     const int r = std::max( 2,
                             ( vconf.isEnlarged()
                               ? vconf.scale( 0.25 )
@@ -302,8 +314,8 @@ DebugPainter::drawBall( QPainter & painter,
         {
             bpos += bvel;
             bvel *= ball_decay;
-            bx = vconf.getScreenX( bpos.x );
-            by = vconf.getScreenY( bpos.y );
+            bx = vconf.screenX( bpos.x );
+            by = vconf.screenY( bpos.y );
             painter.drawEllipse( bx - 2, by - 2,
                                  4, 4 );
         }
@@ -320,7 +332,8 @@ DebugPainter::drawBall( QPainter & painter,
 
         painter.drawText( ix - r,
                           iy + r + painter.fontMetrics().ascent(),
-                          QString::fromAscii( ball->comment_.c_str() ) );
+                          ball->comment_ );
+                          //QString::fromAscii( ball->comment_.c_str() ) );
     }
 }
 
@@ -338,7 +351,9 @@ DebugPainter::drawPlayers( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( player_side == rcsc::RIGHT ? -1.0 : 1.0 );
+    const double reverse = ( vconf.reverseValue()
+                             * ( player_side == rcsc::RIGHT ? -1.0 : 1.0 ) );
+
     const bool comment = vconf.isShownDebugViewComment();
     const int r = std::max( 2,
                             ( vconf.isEnlarged()
@@ -350,12 +365,13 @@ DebugPainter::drawPlayers( QPainter & painter,
           it != end;
           ++it )
     {
-        const int ix = vconf.getScreenX( (double)(*it)->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
-        const int iy = vconf.getScreenY( (double)(*it)->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+        const int ix = vconf.screenX( (double)(*it)->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+        const int iy = vconf.screenY( (double)(*it)->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
 
         if ( (*it)->body_ != -360 )
         {
             double body_start_dir = - ( (double)(*it)->body_ + 90.0 );
+            if ( vconf.reverseSide() ) body_start_dir += 180.0;
             if ( player_side == rcsc::RIGHT ) body_start_dir -= 180.0;
             //double body_end_dir = body_start_dir + 180.0;
             // draw body half circle
@@ -404,7 +420,8 @@ DebugPainter::drawPlayers( QPainter & painter,
 
             painter.drawText( ix - r,
                               iy + r + painter.fontMetrics().ascent(),
-                              QString::fromAscii( (*it)->comment_.c_str() ) );
+                              (*it)->comment_ );
+                              //QString::fromAscii( (*it)->comment_.c_str() ) );
         }
     }
 }
@@ -426,20 +443,21 @@ DebugPainter::drawLines( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( player_side == rcsc::RIGHT ? -1.0 : 1.0 );
+    const double reverse = ( vconf.reverseValue()
+                             * ( player_side == rcsc::RIGHT ? -1.0 : 1.0 ) );
 
     painter.setPen( dconf.debugFigurePen() );
     painter.setBrush( dconf.transparentBrush() );
 
-     const std::list< DebugViewData::LineT >::const_iterator end = view.lines().end();
+    const std::list< DebugViewData::LineT >::const_iterator end = view.lines().end();
     for ( std::list< DebugViewData::LineT >::const_iterator it = view.lines().begin();
           it != end;
           ++it )
     {
-        painter.drawLine( vconf.getScreenX( it->x1_ * reverse ),
-                          vconf.getScreenY( it->y1_ * reverse ),
-                          vconf.getScreenX( it->x2_ * reverse ),
-                          vconf.getScreenY( it->y2_ * reverse ) );
+        painter.drawLine( vconf.screenX( it->x1_ * reverse ),
+                          vconf.screenY( it->y1_ * reverse ),
+                          vconf.screenX( it->x2_ * reverse ),
+                          vconf.screenY( it->y2_ * reverse ) );
     }
 }
 
@@ -460,7 +478,8 @@ DebugPainter::drawTriangles( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( player_side == rcsc::RIGHT ? -1.0 : 1.0 );
+    const double reverse = ( vconf.reverseValue()
+                             * ( player_side == rcsc::RIGHT ? -1.0 : 1.0 ) );
 
     painter.setPen( dconf.debugFigurePen() );
     painter.setBrush( dconf.transparentBrush() );
@@ -470,12 +489,12 @@ DebugPainter::drawTriangles( QPainter & painter,
           it != end;
           ++it )
     {
-        int x1 = vconf.getScreenX( it->x1_ * reverse );
-        int y1 = vconf.getScreenY( it->y1_ * reverse );
-        int x2 = vconf.getScreenX( it->x2_ * reverse );
-        int y2 = vconf.getScreenY( it->y2_ * reverse );
-        int x3 = vconf.getScreenX( it->x3_ * reverse );
-        int y3 = vconf.getScreenY( it->y3_ * reverse );
+        int x1 = vconf.screenX( it->x1_ * reverse );
+        int y1 = vconf.screenY( it->y1_ * reverse );
+        int x2 = vconf.screenX( it->x2_ * reverse );
+        int y2 = vconf.screenY( it->y2_ * reverse );
+        int x3 = vconf.screenX( it->x3_ * reverse );
+        int y3 = vconf.screenY( it->y3_ * reverse );
 
         painter.drawLine( x1, y1,
                           x2, y2 );
@@ -503,7 +522,9 @@ DebugPainter::drawRectangles( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( player_side == rcsc::RIGHT ? -1.0 : 1.0 );
+    const double reverse = ( vconf.reverseValue()
+                             * ( player_side == rcsc::RIGHT ? -1.0 : 1.0 ) );
+
     painter.setPen( dconf.debugFigurePen() );
     painter.setBrush( dconf.transparentBrush() );
 
@@ -512,10 +533,10 @@ DebugPainter::drawRectangles( QPainter & painter,
           it != end;
           ++it )
     {
-        int left_x = vconf.getScreenX( it->left_x_ * reverse );
-        int top_y = vconf.getScreenY( it->top_y_ * reverse );
-        int right_x = vconf.getScreenX( it->right_x_ * reverse );
-        int bottom_y = vconf.getScreenY( it->bottom_y_ * reverse );
+        int left_x = vconf.screenX( it->left_x_ * reverse );
+        int top_y = vconf.screenY( it->top_y_ * reverse );
+        int right_x = vconf.screenX( it->right_x_ * reverse );
+        int bottom_y = vconf.screenY( it->bottom_y_ * reverse );
 
         painter.drawRect( left_x,
                           top_y,
@@ -541,7 +562,8 @@ DebugPainter::drawCircles( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( player_side == rcsc::RIGHT ? -1.0 : 1.0 );
+    const double reverse = ( vconf.reverseValue()
+                             * ( player_side == rcsc::RIGHT ? -1.0 : 1.0 ) );
 
     painter.setPen( dconf.debugFigurePen() );
     painter.setBrush( dconf.transparentBrush() );
@@ -552,8 +574,8 @@ DebugPainter::drawCircles( QPainter & painter,
           ++it )
     {
         int r = vconf.scale( it->radius_ );
-        painter.drawEllipse( vconf.getScreenX( it->center_x_ * reverse ) - r,
-                             vconf.getScreenY( it->center_y_ * reverse ) - r,
+        painter.drawEllipse( vconf.screenX( it->center_x_ * reverse ) - r,
+                             vconf.screenY( it->center_y_ * reverse ) - r,
                              r * 2,
                              r * 2 );
     }
@@ -575,5 +597,6 @@ DebugPainter::drawMessage( QPainter & painter,
     painter.drawText( 10,
                       M_main_data.viewConfig().scoreBoardHeight()
                       + painter.fontMetrics().ascent() + 2,
-                      QString::fromAscii( message.c_str() ) );
+                      message );
+                      //QString::fromAscii( message.c_str() ) );
 }
