@@ -200,6 +200,11 @@ DetailDialog::createPlayerLabels()
     layout->addWidget( M_player_polar_vel, row, 1, Qt::AlignRight );
     ++row;
 
+    layout->addWidget( new QLabel( tr( "MaxTurn " ), group_box ),
+                       row, 0, Qt::AlignRight );
+    M_max_turn_moment = new QLabel( tr( " 180.00" ), group_box );
+    layout->addWidget( M_max_turn_moment, row, 1, Qt::AlignRight );
+    ++row;
 
     layout->addWidget( new QLabel( tr( "LastMove " ), group_box ),
                        row, 0, Qt::AlignRight );
@@ -342,6 +347,8 @@ DetailDialog::updateLabels()
         return;
     }
 
+    const ViewConfig & vconf = M_main_data.viewConfig();
+
     MonitorViewConstPtr last_view
         = ( M_main_data.viewIndex() <= 0
             ? MonitorViewConstPtr()
@@ -349,6 +356,8 @@ DetailDialog::updateLabels()
 
     //std::cerr << "DetailDialog::updteLabels start" << std::endl;
 
+    const double reverse = vconf.reverseValue();
+
     char buf[32];
 
     // update ball
@@ -356,12 +365,14 @@ DetailDialog::updateLabels()
     const Ball & ball = view->ball();
 
     std::snprintf( buf, 32, " %6.2f, %6.2f",
-                   ball.x(), ball.y() );
+                   ball.x() * reverse,
+                   ball.y() * reverse );
     M_ball_pos->setText( QString::fromAscii( buf ) );
 
     if ( ball.hasDelta() )
     {
         rcsc::Vector2D vel( ball.deltaX(), ball.deltaY() );
+        vel *= reverse;
         std::snprintf( buf, 32, " %6.2f, %6.2f",
                        vel.x, vel.y );
 				M_ball_vel->setText( QString::fromAscii( buf ) );
@@ -380,6 +391,7 @@ DetailDialog::updateLabels()
     {
         rcsc::Vector2D move( ball.x() - last_view->ball().x(),
                              ball.y() - last_view->ball().y() );
+        move *= reverse;
 
         std::snprintf( buf, 32, " %6.2f, %6.2f",
                        move.x, move.y );
@@ -405,7 +417,9 @@ DetailDialog::updateLabels()
 
     // side, number
     std::snprintf( buf, 32, "%s     %2d",
-                   number > 0 ? "   Left" : "   Right",
+                   ( vconf.reverseSide()
+                     ? ( number > 0 ? "   Right" : "   Left" )
+                     : ( number > 0 ? "   Left" : "   Right" ) ),
                    number > 0 ? number : -number );
     M_player_number->setText( QString::fromAscii( buf ) );
 
@@ -416,13 +430,15 @@ DetailDialog::updateLabels()
 
     // pos
     std::snprintf( buf, 32, " %6.2f, %6.2f",
-                   player.x(), player.y() );
+                   player.x() * reverse,
+                   player.y() * reverse );
 		M_player_pos->setText( QString::fromAscii( buf ) );
 
     // velocity, speed, speed dir
 		if ( player.hasDelta() )
 		{
 				rcsc::Vector2D vel( player.deltaX(), player.deltaY() );
+        vel *= reverse;
 
 				std::snprintf( buf, 32, " %6.2f, %6.2f",
                        vel.x, vel.y );
@@ -436,6 +452,10 @@ DetailDialog::updateLabels()
         std::snprintf( buf, 32, " %6.2f, %6.2f",
                        ball.deltaX() - vel.x, ball.deltaY() - vel.y );
         M_player_ball_rel_vel->setText( QString::fromAscii( buf ) );
+
+        double max_turn = player_type.effectiveTurn( 180.0, vel.r() );
+        std::snprintf( buf, 32, " %3.2f", max_turn );
+        M_max_turn_moment->setText( QString::fromAscii( buf ) );
 		}
 
     if ( ! last_view )
@@ -448,6 +468,8 @@ DetailDialog::updateLabels()
         const Player & last_player = last_view->players()[player_index];
         rcsc::Vector2D last_move( player.x() - last_player.x(),
                                   player.y() - last_player.y() );
+        last_move *= reverse;
+
 				std::snprintf( buf, 32, " %6.2f, %6.2f",
                        last_move.x, last_move.y );
 				M_player_last_move->setText( QString::fromAscii( buf ) );
@@ -458,17 +480,22 @@ DetailDialog::updateLabels()
     }
 
     // body angle
+    rcsc::AngleDeg body = player.body();
+    if ( vconf.reverseSide() ) body += 180.0;
+
     std::snprintf( buf, 32," %6.1f",
-                   player.body() );
+                   body.degree() );
     M_player_body->setText( QString::fromAscii( buf ) );
 
     // neck, head angle
     if ( player.hasView() )
     {
         rcsc::AngleDeg neck = player.head() - player.body();
+        rcsc::AngleDeg head = player.head();
+        if ( vconf.reverseSide() ) head += 180.0;
 
         std::snprintf( buf, 32, " %6.1f(%6.1f)",
-                       player.head(), neck.degree() );
+                       head.degree(), neck.degree() );
         M_player_head->setText( QString::fromAscii( buf ) );
     }
 
@@ -526,7 +553,9 @@ DetailDialog::updateLabels()
 
     // ball related info
     {
-        rcsc::Vector2D player_to_ball( ball.x() - player.x(), ball.y() - player.y() );
+        rcsc::Vector2D player_to_ball( ball.x() - player.x(),
+                                       ball.y() - player.y() );
+        player_to_ball *= reverse;
 
         std::snprintf( buf, 32, " %6.2f, %6.2f",
                        player_to_ball.x, player_to_ball.y );
