@@ -79,6 +79,10 @@ const QColor DrawConfig::DEBUG_OPPONENT_COLOR = QColor( 0, 95, 255 );
 const QColor DrawConfig::DEBUG_UNKNOWN_TEAMMATE_COLOR = QColor( 215, 255, 0 );
 const QColor DrawConfig::DEBUG_UNKNOWN_OPPONENT_COLOR = QColor( 127, 95, 255 );
 const QColor DrawConfig::DEBUG_UNKNOWN_PLAYER_COLOR = QColor( 191, 191, 191 );
+const QColor DrawConfig::DEBUG_COMMENT_FONT_COLOR = QColor( 191, 191, 191 );
+const QColor DrawConfig::DEBUG_MESSAGE_FONT_COLOR = QColor( 255, 255, 255 );
+const QColor DrawConfig::DEBUG_LOG_MESSAGE_FONT_COLOR = QColor( 0, 0, 0 );
+const QColor DrawConfig::DEBUG_FIGURE_COLOR = QColor( 255, 127, 0 );
 
 /*-------------------------------------------------------------------*/
 /*!
@@ -144,11 +148,13 @@ DrawConfig::DrawConfig()
     , M_debug_unknown_opponent_brush( DEBUG_UNKNOWN_OPPONENT_COLOR, Qt::SolidPattern )
     , M_debug_unknown_player_brush( DEBUG_UNKNOWN_PLAYER_COLOR, Qt::SolidPattern )
     , M_debug_target_pen( DEBUG_SELF_COLOR, 2, Qt::SolidLine )
-    , M_debug_figure_pen( QColor( 255, 127, 0 ), 1, Qt::SolidLine )
     , M_debug_comment_font( "Sans Serif", 10 )
-    , M_debug_comment_font_pen( QColor( 191, 191, 191 ), 0, Qt::SolidLine )
+    , M_debug_comment_font_pen( DEBUG_COMMENT_FONT_COLOR, 0, Qt::SolidLine )
     , M_debug_message_font( "Sans Serif", 14 )
-    , M_debug_message_font_pen( QColor( 255, 255, 255 ), 0, Qt::SolidLine )
+    , M_debug_message_font_pen( DEBUG_MESSAGE_FONT_COLOR, 0, Qt::SolidLine )
+    , M_debug_log_message_font( "Sans Serif", 8 )
+    , M_debug_log_message_font_pen( DEBUG_LOG_MESSAGE_FONT_COLOR, 0, Qt::SolidLine )
+    , M_debug_figure_pen( DEBUG_FIGURE_COLOR, 1, Qt::SolidLine )
 {
     //std::cerr << "create DrawConfig" << std::endl;
     loadSettings();
@@ -230,9 +236,11 @@ DrawConfig::setDefaultColors()
     M_debug_unknown_opponent_brush.setColor( DEBUG_UNKNOWN_OPPONENT_COLOR );
     M_debug_unknown_player_brush.setColor( DEBUG_UNKNOWN_PLAYER_COLOR );
     M_debug_target_pen.setColor( DEBUG_SELF_COLOR );
-    M_debug_figure_pen.setColor( QColor( 255, 127, 0 ) );
-    M_debug_comment_font_pen.setColor( QColor( 191, 191, 191 ) );
-    M_debug_message_font_pen.setColor( QColor( 255, 255, 255 ) );
+    M_debug_comment_font_pen.setColor( DEBUG_COMMENT_FONT_COLOR );
+    M_debug_message_font_pen.setColor( DEBUG_MESSAGE_FONT_COLOR );
+    M_debug_log_message_font_pen.setColor( DEBUG_LOG_MESSAGE_FONT_COLOR );
+    M_debug_figure_pen.setColor( DEBUG_FIGURE_COLOR );
+
 }
 
 /*-------------------------------------------------------------------*/
@@ -259,6 +267,9 @@ DrawConfig::setDefaultFonts()
 
     M_debug_message_font.setFamily( "Sans Serif" );
     M_debug_message_font.setPointSize( 14 );
+
+    M_debug_log_message_font.setFamily( "Sans Serif" );
+    M_debug_log_message_font.setPointSize( 8 );
 }
 
 /*-------------------------------------------------------------------*/
@@ -553,12 +564,6 @@ DrawConfig::loadSettings()
         M_debug_target_pen.setColor( toColor( val ) );
     }
 
-    val = settings.readEntry( "debug_figure_pen_color" );
-    if ( ! val.isEmpty() )
-    {
-        M_debug_figure_pen.setColor( toColor( val ) );
-    }
-
     val = settings.readEntry( "debug_comment_font_color" );
     if ( ! val.isEmpty() )
     {
@@ -571,6 +576,18 @@ DrawConfig::loadSettings()
         M_debug_message_font_pen.setColor( toColor( val ) );
     }
 
+    val = settings.readEntry( "debug_log_message_font_color" );
+    if ( ! val.isEmpty() )
+    {
+        M_debug_log_message_font_pen.setColor( toColor( val ) );
+    }
+
+    val = settings.readEntry( "debug_figure_pen_color" );
+    if ( ! val.isEmpty() )
+    {
+        M_debug_figure_pen.setColor( toColor( val ) );
+    }
+
     settings.endGroup();
 }
 
@@ -690,13 +707,16 @@ DrawConfig::saveSettings()
                          toString( debugUnknownPlayerBrush().color() ) );
     settings.writeEntry( "debug_target_pen_color",
                          toString( debugTargetPen().color() ) );
-    settings.writeEntry( "debug_figure_pen_color",
-                         toString( debugFigurePen().color() ) );
     settings.writeEntry( "debug_comment_font_color",
                          toString( debugCommentFontPen().color() ) );
     settings.writeEntry( "debug_message_font_color",
                          toString( debugMessageFontPen().color() ) );
 
+    settings.writeEntry( "debug_log_message_font_color",
+                         toString( debugLogMessageFontPen().color() ) );
+    settings.writeEntry( "debug_figure_pen_color",
+                         toString( debugFigurePen().color() ) );
+
     settings.endGroup();
 }
 
