@@ -87,6 +87,10 @@ public:
     static const QColor DEBUG_UNKNOWN_TEAMMATE_COLOR;
     static const QColor DEBUG_UNKNOWN_OPPONENT_COLOR;
     static const QColor DEBUG_UNKNOWN_PLAYER_COLOR;
+    static const QColor DEBUG_COMMENT_FONT_COLOR;
+    static const QColor DEBUG_MESSAGE_FONT_COLOR;
+    static const QColor DEBUG_LOG_MESSAGE_FONT_COLOR;
+    static const QColor DEBUG_FIGURE_COLOR;
 
 private:
 
@@ -200,7 +204,7 @@ private:
     QPen M_measure_font_pen; //!< color of mouse measure font
 
     //--------------------------------------------------
-    // debug
+    // debug view
 
     // ball
     QPen M_debug_ball_pen;
@@ -222,15 +226,21 @@ private:
     // target
     QPen M_debug_target_pen;
 
-    // line, triangle, rectanble, circle
-    QPen M_debug_figure_pen;
-
     // message
     QFont M_debug_comment_font;
     QPen M_debug_comment_font_pen;
     QFont M_debug_message_font;
     QPen M_debug_message_font_pen;
 
+    //--------------------------------------------------
+    // debug log view
+
+    QFont M_debug_log_message_font;
+    QPen M_debug_log_message_font_pen;
+
+    // line, triangle, rectanble, circle
+    QPen M_debug_figure_pen;
+
     //! constructor
     DrawConfig();
     DrawConfig( const DrawConfig & );
@@ -857,16 +867,6 @@ public:
           return M_debug_target_pen;
       }
 
-    QPen * debugFigurePenPtr()
-      {
-          return &M_debug_figure_pen;
-      }
-    const
-    QPen & debugFigurePen() const
-      {
-          return M_debug_figure_pen;
-      }
-
     QFont * debugCommentFontPtr()
       {
           return &M_debug_comment_font;
@@ -906,6 +906,37 @@ public:
       {
           return M_debug_message_font_pen;
       }
+
+    QFont * debugLogMessageFontPtr()
+      {
+          return &M_debug_log_message_font;
+      }
+    const
+    QFont & debugLogMessageFont() const
+      {
+          return M_debug_log_message_font;
+      }
+
+    QPen * debugLogMessageFontPenPtr()
+      {
+          return &M_debug_log_message_font_pen;
+      }
+    const
+    QPen & debugLogMessageFontPen() const
+      {
+          return M_debug_log_message_font_pen;
+      }
+
+    QPen * debugFigurePenPtr()
+      {
+          return &M_debug_figure_pen;
+      }
+    const
+    QPen & debugFigurePen() const
+      {
+          return M_debug_figure_pen;
+      }
+
 };
 
 #endif
