@@ -5,18 +5,19 @@
 #include "app_config.h"
 
 int
-main( int argc,
-      char ** argv )
+main( int argc, char ** argv )
 {
     QApplication app( argc, argv );
     //QApplication::setStyle( "platinum" );
 
-    if ( ! AppConfig::instance().parseCmdLine( argc, argv ) )
+    if ( ! AppConfig::instance().parseCmdLine( app.argc(), app.argv() ) )
+    //if ( ! AppConfig::instance().parseCmdLine( argc, argv ) )
     {
         return 1;
     }
 
     MainWindow win;
+    app.setMainWidget( &win );
     win.show();
     win.init();
 
