@@ -41,6 +41,7 @@
 #include "detail_dialog.h"
 #include "font_setting_dialog.h"
 #include "image_save_dialog.h"
+#include "launcher_dialog.h"
 #include "player_type_dialog.h"
 #include "view_config_dialog.h"
 #include "debug_message_window.h"
@@ -64,9 +65,10 @@
 #include "xpm/soccerwindow2.xpm"
 #include "xpm/soccerwindow2-nostr.xpm"
 
-#include "xpm/open_rcg.xpm"
 #include "xpm/debug_server_switch.xpm"
 #include "xpm/logplayer_live_mode.xpm"
+#include "xpm/open_rcg.xpm"
+#include "xpm/save.xpm"
 
 #ifndef PACKAGENAME
 #define PACKAGENAME "soccerwindow2"
@@ -81,12 +83,11 @@ MainWindow::MainWindow()
     , M_detail_dialog( static_cast< DetailDialog * >( 0 ) )
     , M_player_type_dialog( static_cast< PlayerTypeDialog * >( 0 ) )
     , M_view_config_dialog( static_cast< ViewConfigDialog * >( 0 ) )
+    , M_launcher_dialog( static_cast< LauncherDialog * >( 0 ) )
     , M_debug_message_window( static_cast< DebugMessageWindow * >( 0 ) )
     , M_monitor_client( static_cast< MonitorClient * >( 0 ) )
-    , M_debug_server_running( false )
-    , M_cursor_override( false )
+    , M_last_connected_host( "localhost" )
 {
-    //    QPixmapCache::setCacheLimit( 1024 * 24 );
     loadSettings();
 
     createActions();
@@ -142,6 +143,10 @@ MainWindow::MainWindow()
         this->showFullScreen();
     }
 
+    if ( AppConfig::instance().hideMenuBar() )
+    {
+        this->menuBar()->hide();
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -168,7 +173,8 @@ MainWindow::init()
 {
     if ( ! AppConfig::instance().gameLogFilePath().empty() )
     {
-        loadRCG( QString::fromAscii( AppConfig::instance().gameLogFilePath().c_str() ) );
+        //loadRCG( QString::fromAscii( AppConfig::instance().gameLogFilePath().c_str() ) );
+        loadRCG( AppConfig::instance().gameLogFilePath() );
         return;
     }
 
@@ -235,9 +241,9 @@ MainWindow::saveSettings()
     settings.beginGroup( "/.soccerwindow2-qt3./AppConfig" );
 
     settings.writeEntry( "gameLogDir",
-                         QString( AppConfig::instance().gameLogDir().c_str() ) );
+                         QString( AppConfig::instance().gameLogDir() ) );
     settings.writeEntry( "debugLogDir",
-                         QString( AppConfig::instance().debugLogDir().c_str() ) );
+                         QString( AppConfig::instance().debugLogDir() ) );
 
     settings.endGroup();
 }
@@ -272,13 +278,15 @@ MainWindow::createActionsFile()
     M_open_rcg_act->setStatusTip( tr( "Open RoboCup Game Log file" ) );
     connect( M_open_rcg_act, SIGNAL( activated() ), this, SLOT( openRCG() ) );
 
-    M_save_rcg_act = new QAction( tr( "Save rcg file as..." ),
+    M_save_rcg_act = new QAction( QIconSet( QPixmap( save_xpm ) ),
+                                  tr( "Save rcg file as..." ),
                                   QKeySequence(),
                                   this );
     M_save_rcg_act->setStatusTip( tr( "Save RoboCup Game Log file" ) );
     connect( M_save_rcg_act, SIGNAL( activated() ), this, SLOT( saveRCG() ) );
 
-    M_open_debug_view_act = new QAction( tr( "Open debug view" ),
+    M_open_debug_view_act = new QAction( QIconSet( QPixmap( open_rcg_xpm ) ),
+                                         tr( "Open debug view" ),
                                          QKeySequence(),
                                          this );
     M_open_debug_view_act
@@ -286,7 +294,8 @@ MainWindow::createActionsFile()
     connect( M_open_debug_view_act, SIGNAL( activated() ),
              this, SLOT( openDebugView() ) );
 
-    M_save_debug_view_act = new QAction( tr( "Save debug view" ),
+    M_save_debug_view_act = new QAction( QIconSet( QPixmap( save_xpm ) ),
+                                         tr( "Save debug view" ),
                                          QKeySequence(),
                                          this );
     M_save_debug_view_act
@@ -368,6 +377,14 @@ MainWindow::createActionsMonitor()
     M_restart_server_act->setStatusTip( tr( "(Re)start rcssserver" ) );
     connect( M_restart_server_act, SIGNAL( activated() ),
              this, SLOT( restartServer() ) );
+
+    M_show_launcher_dialog_act = new QAction( tr( "Launcher Dialog" ),
+                                              QKeySequence(),
+                                              this );
+    M_show_launcher_dialog_act->setAccel( tr( "Ctrl+X" ) );
+    M_show_launcher_dialog_act->setStatusTip( tr( "Show launcher dialog" ) );
+    connect( M_show_launcher_dialog_act, SIGNAL( activated() ),
+             this, SLOT( showLauncherDialog() ) );
 }
 
 /*-------------------------------------------------------------------*/
@@ -377,6 +394,14 @@ MainWindow::createActionsMonitor()
 void
 MainWindow::createActionsView()
 {
+     M_toggle_menu_bar_act = new QAction( tr( "&Menu Bar" ),
+                                          QKeySequence(),
+                                          this );
+     M_toggle_menu_bar_act->setStatusTip( tr( "Show/Hide Menu Bar" ) );
+     M_toggle_menu_bar_act->setAccel( tr( "Ctrl+M" ) );
+     connect( M_toggle_menu_bar_act, SIGNAL( activated() ),
+              this, SLOT( toggleMenuBar() ) );
+
     M_toggle_tool_bar_act = new QAction( tr( "&Tool Bar" ),
                                          QKeySequence(),
                                          this );
@@ -394,7 +419,7 @@ MainWindow::createActionsView()
     M_full_screen_act = new QAction( tr( "&Full Screen" ),
                                      QKeySequence(),
                                      this );
-    M_full_screen_act->setAccel( tr( "Alt+Enter" ) );
+    M_full_screen_act->setAccel( Qt::Key_F11 ); //tr( "Alt+Enter" ) );
     //M_full_screen_act->setAccel( tr( "Alt+Enter" ) );
     //M_full_screen_act->setAccel( Qt::ALT + Qt::Key_Return );
     //M_full_screen_act->setAccel( Qt::ALT + Qt::Key_Enter );
@@ -410,6 +435,10 @@ MainWindow::createActionsView()
         QAccel * accel = new QAccel( this );
         accel->connectItem( accel->insertItem( Qt::ALT + Qt::Key_Return ),
                             this, SLOT( toggleFullScreen() ) );
+        accel->connectItem( accel->insertItem( Qt::ALT + Qt::Key_Enter ),
+                            this, SLOT( toggleFullScreen() ) );
+        //accel->connectItem( accel->insertItem( Qt::Key_F11 ),
+        //                    this, SLOT( toggleFullScreen() ) );
     }
 
     M_show_player_type_dialog_act = new QAction( tr( "&Player Type List" ),
@@ -495,29 +524,18 @@ MainWindow::createActionsTool()
     connect( M_show_debug_message_window_act, SIGNAL( activated() ),
              this, SLOT( showDebugMessageWindow() ) );
 
-    M_start_debug_server_act = new QAction( QIconSet( QPixmap( debug_server_switch_xpm ) ),
-                                            tr( "Debug Server Mode" ),
-                                            QKeySequence(),
-                                            this );
-    M_start_debug_server_act->setAccel( tr( "Ctrl+S" ) );
-    M_start_debug_server_act
+    M_toggle_debug_server_mode_act
+        = new QAction( QIconSet( QPixmap( debug_server_switch_xpm ) ),
+                       tr( "Debug Server Mode" ),
+                       QKeySequence(),
+                       this );
+    M_toggle_debug_server_mode_act->setAccel( tr( "Ctrl+S" ) );
+    M_toggle_debug_server_mode_act
         ->setStatusTip( tr( "Start/Stop the debug server." ) );
-    M_start_debug_server_act->setEnabled( false );
-    M_start_debug_server_act->setToggleAction( true );
-    //connect( M_start_debug_server_act, SIGNAL( activated() ),
-    //this, SLOT( startDebugServer() ) );
-    connect( M_start_debug_server_act, SIGNAL( toggled( bool ) ),
+    M_toggle_debug_server_mode_act->setEnabled( false );
+    M_toggle_debug_server_mode_act->setToggleAction( true );
+    connect( M_toggle_debug_server_mode_act, SIGNAL( toggled( bool ) ),
              this, SLOT( toggleDebugServer( bool ) ) );
-#if 0
-    M_stop_debug_server_act = new QAction( tr( "Stop Debug Server" ),
-                                           QKeySequence(),
-                                           this );
-    M_stop_debug_server_act
-        ->setStatusTip( tr( "Disconnect debug connections and stop the debug server." ) );
-    M_stop_debug_server_act->setEnabled( false );
-    connect( M_stop_debug_server_act, SIGNAL( activated() ),
-             this, SLOT( stopDebugServer() ) );
-#endif
     M_show_image_save_dialog_act = new QAction( tr( "Save &Image" ),
                                                 QKeySequence(),
                                                 this );
@@ -594,6 +612,8 @@ MainWindow::createMenuMonitor()
     menu->insertSeparator();
     M_kill_server_act->addTo( menu );
     M_restart_server_act->addTo( menu );
+    menu->insertSeparator();
+    M_show_launcher_dialog_act->addTo( menu );
 
     menuBar()->insertItem( tr( "&Monitor" ), menu );
 }
@@ -607,6 +627,7 @@ MainWindow::createMenuView()
 {
     QPopupMenu * menu = new QPopupMenu( this );
     menu->insertTearOffHandle();
+    M_toggle_menu_bar_act->addTo( menu );
     M_toggle_tool_bar_act->addTo( menu );
     M_toggle_status_bar_act->addTo( menu );
     menu->insertSeparator();
@@ -638,8 +659,7 @@ MainWindow::createMenuTool()
     menu->insertTearOffHandle();
     M_show_debug_message_window_act->addTo( menu );
     menu->insertSeparator();
-    M_start_debug_server_act->addTo( menu );
-    //M_stop_debug_server_act->addTo( menu );
+    M_toggle_debug_server_mode_act->addTo( menu );
     menu->insertSeparator();
     M_show_image_save_dialog_act->addTo( menu );
 
@@ -672,7 +692,7 @@ MainWindow::createToolBars()
     M_log_player_tool_bar->addSeparator();
 
     M_set_live_mode_act->addTo( M_log_player_tool_bar );
-    M_start_debug_server_act->addTo( M_log_player_tool_bar );
+    M_toggle_debug_server_mode_act->addTo( M_log_player_tool_bar );
 
     connect( this, SIGNAL( viewUpdated() ),
              M_log_player_tool_bar, SLOT( updateSlider() ) );
@@ -806,123 +826,99 @@ MainWindow::createViewConfigDialog()
     connect( M_field_canvas, SIGNAL( focusChanged( const QPoint & ) ),
              M_view_config_dialog, SLOT( setFocusPoint( const QPoint & ) ) );
 
-    connect( M_view_config_dialog, SIGNAL( configured() ),
-             M_field_canvas, SLOT( setRedrawAllFlag()  ) );
-
-    QAccel * accel = new QAccel( this );
-    // register short cut keys
     {
+        // register short cut keys
+        QAccel * accel = new QAccel( this );
+
+        // zoom
         // z
         accel->connectItem( accel->insertItem( Qt::Key_Z ),
                             M_view_config_dialog, SLOT( zoomIn() ) );
-    }
-    {
+        // +
+        accel->connectItem( accel->insertItem( Qt::Key_Plus ),
+                            M_view_config_dialog, SLOT( zoomIn() ) );
         // x
         accel->connectItem( accel->insertItem( Qt::Key_X ),
                             M_view_config_dialog, SLOT( zoomOut() ) );
-    }
-    {
+        // Ctrl + +
+        accel->connectItem( accel->insertItem( Qt::CTRL + Qt::Key_Plus ),
+                            M_view_config_dialog, SLOT( zoomOut() ) );
         // Ctrl + z
         accel->connectItem( accel->insertItem( Qt::CTRL + Qt::Key_Z ),
                             M_view_config_dialog, SLOT( zoomOut() ) );
-    }
-    {
         // i
         accel->connectItem( accel->insertItem( Qt::Key_I ),
                             M_view_config_dialog, SLOT( unzoom() ) );
-    }
-    {
         // e
         accel->connectItem( accel->insertItem( Qt::Key_E ),
                             M_view_config_dialog, SLOT( toggleEnlarge() ) );
-    }
 
-    {
-        // k
-        accel->connectItem( accel->insertItem( Qt::Key_K ),
-                            M_view_config_dialog, SLOT( toggleKeepawayMode() ) );
-    }
+        // reverse mode
+        // Ctrl + r
+        accel->connectItem( accel->insertItem( Qt::CTRL + Qt::Key_R ),
+                            M_view_config_dialog, SLOT( toggleReverseSide() ) );
+        // Ctrl + Shift + r
+        accel->connectItem( accel->insertItem( Qt::CTRL + Qt::SHIFT + Qt::Key_R ),
+                            M_view_config_dialog, SLOT( togglePlayerReverseDraw() ) );
 
-    // player detail
-    {
+        // player detail
         // n
         accel->connectItem( accel->insertItem( Qt::Key_N ),
                             M_view_config_dialog, SLOT( toggleShowPlayerNumber() ) );
-    }
-    {
         // h
         accel->connectItem( accel->insertItem( Qt::Key_H ),
                             M_view_config_dialog, SLOT( toggleShowHeteroNumber() ) );
-    }
-    {
         // s
         accel->connectItem( accel->insertItem( Qt::Key_S ),
                             M_view_config_dialog, SLOT( toggleShowStamina() ) );
-    }
-    {
         // v
         accel->connectItem( accel->insertItem( Qt::Key_V ),
                             M_view_config_dialog, SLOT( toggleShowViewCone() ) );
-    }
-    {
         // c
         accel->connectItem( accel->insertItem( Qt::Key_C ),
                             M_view_config_dialog, SLOT( toggleShowControlArea() ) );
-    }
 
-    // show/hide
-    {
+        // show/hide
         // t
         accel->connectItem( accel->insertItem( Qt::Key_T ),
                             M_view_config_dialog, SLOT( toggleShowScoreBoard() ) );
-    }
-    {
         // Ctrl + b
         accel->connectItem( accel->insertItem( Qt::CTRL + Qt::Key_B ),
                             M_view_config_dialog, SLOT( toggleShowBall() ) );
-    }
-    {
         // Ctrl + p
         accel->connectItem( accel->insertItem( Qt::CTRL + Qt::Key_P ),
                             M_view_config_dialog, SLOT( toggleShowPlayers() ) );
-    }
-    {
         // f
         accel->connectItem( accel->insertItem( Qt::Key_F ),
                             M_view_config_dialog, SLOT( toggleShowFlags() ) );
-    }
-    {
         // o
         accel->connectItem( accel->insertItem( Qt::Key_O ),
                             M_view_config_dialog, SLOT( toggleShowOffsideLine() ) );
-    }
-    // b
-    {
+
+        // grass type
+        // k
+        accel->connectItem( accel->insertItem( Qt::Key_K ),
+                            M_view_config_dialog, SLOT( toggleKeepawayMode() ) );
+
+        // focus
+        // b
         accel->connectItem( accel->insertItem( Qt::Key_B ),
                             M_view_config_dialog, SLOT( toggleFocusBall() ) );
-    }
-    // p
-    {
+        // p
         accel->connectItem( accel->insertItem( Qt::Key_P ),
                             M_view_config_dialog, SLOT( toggleFocusPlayer() ) );
-    }
-    // a
-    {
+
+        // player selection
+        // a
         accel->connectItem( accel->insertItem( Qt::Key_A ),
                             M_view_config_dialog, SLOT( toggleSelectAutoAll() ) );
-    }
-    // l
-    {
+        // l
         accel->connectItem( accel->insertItem( Qt::Key_L ),
                             M_view_config_dialog, SLOT( toggleSelectAutoLeft() ) );
-    }
-    // r
-    {
+        // r
         accel->connectItem( accel->insertItem( Qt::Key_R ),
                             M_view_config_dialog, SLOT( toggleSelectAutoRight() ) );
-    }
-    // u
-    {
+        // u
         accel->connectItem( accel->insertItem( Qt::Key_U ),
                             M_view_config_dialog, SLOT( setUnselect() ) );
     }
@@ -953,13 +949,13 @@ MainWindow::createViewConfigDialog()
 /*!
 
 */
-void
-MainWindow::closeEvent( QCloseEvent * event )
-{
-    event->ignore();
+// void
+// MainWindow::closeEvent( QCloseEvent * event )
+// {
+//     event->ignore();
 
-    qApp->quit();
-}
+//     qApp->quit();
+// }
 
 /*-------------------------------------------------------------------*/
 /*!
@@ -1113,10 +1109,10 @@ MainWindow::saveRCG()
             default_file_name
                 = QDateTime::currentDateTime().toString( "yyyyMMddhhmm-" );
 
-            QString left_team( latest->leftTeam().name().c_str() );
+            QString left_team( latest->leftTeam().name() );
             QString left_score = QString::number( latest->leftTeam().score() );
 
-            QString right_team( latest->rightTeam().name().c_str() );
+            QString right_team( latest->rightTeam().name() );
             QString right_score = QString::number( latest->rightTeam().score() );
 
             default_file_name += left_team;
@@ -1139,7 +1135,7 @@ MainWindow::saveRCG()
                         "All files (*)" ) );
 #endif
 
-    QString default_dir( AppConfig::instance().gameLogDir().c_str() );
+    QString default_dir( AppConfig::instance().gameLogDir() );
     if ( ! default_file_name.isEmpty() )
     {
         default_dir += tr( "/" );
@@ -1207,7 +1203,7 @@ MainWindow::openDebugView()
 {
     //std::cerr << "MainWindow::openDebugView()" << std::endl;
 
-    QString default_dir( AppConfig::instance().debugLogDir().c_str() );
+    QString default_dir( AppConfig::instance().debugLogDir() );
 #if 1
     QString dir_path
         = QFileDialog::getExistingDirectory( default_dir,
@@ -1336,7 +1332,7 @@ MainWindow::connectMonitorTo()
     QString text = QInputDialog::getText( tr( "Input sserver host name" ),
                                           tr( "Host name: "),
                                           QLineEdit::Normal,
-                                          tr( "localhost" ),
+                                          M_last_connected_host,
                                           & ok,
                                           this );
     if ( ok
@@ -1375,6 +1371,8 @@ MainWindow::connectMonitorTo( const char * hostname )
         return;
     }
 
+    M_last_connected_host = hostname;
+
     // reset all data
     M_main_data.clear();
 
@@ -1393,7 +1391,7 @@ MainWindow::connectMonitorTo( const char * hostname )
         M_view_config_dialog->unzoom();
     }
 
-    if ( M_debug_server_running )
+    if ( M_toggle_debug_server_mode_act->isOn() )
     {
         stopDebugServer();
         startDebugServer();
@@ -1410,8 +1408,7 @@ MainWindow::connectMonitorTo( const char * hostname )
     M_disconnect_monitor_act->setEnabled( true );
     M_kill_server_act->setEnabled( true );
 
-    M_start_debug_server_act->setEnabled( true );
-    //M_stop_debug_server_act->setEnabled( false );
+    M_toggle_debug_server_mode_act->setEnabled( true );
     M_show_image_save_dialog_act->setEnabled( false );
 
     connect( M_monitor_client.get(), SIGNAL( received() ),
@@ -1424,10 +1421,9 @@ MainWindow::connectMonitorTo( const char * hostname )
     // this method will be called automatically.
     //M_monitor_client->sendDispInit();
 
-    if ( M_cursor_override )
+    if ( QApplication::overrideCursor() )
     {
         QApplication::restoreOverrideCursor();
-        M_cursor_override = false;
     }
 }
 
@@ -1439,6 +1435,7 @@ void
 MainWindow::disconnectMonitor()
 {
     //std::cerr << "MainWindow::disconnectMonitor()" << std::endl;
+
     if ( M_monitor_client )
     {
         M_monitor_client->disconnect();
@@ -1468,8 +1465,7 @@ MainWindow::disconnectMonitor()
     M_disconnect_monitor_act->setEnabled( false );
     M_kill_server_act->setEnabled( false );
 
-    M_start_debug_server_act->setEnabled( false );
-    //M_stop_debug_server_act->setEnabled( false );
+    M_toggle_debug_server_mode_act->setEnabled( false );
     M_show_image_save_dialog_act->setEnabled( true );
 }
 
@@ -1510,25 +1506,31 @@ MainWindow::killServer()
 void
 MainWindow::startServer()
 {
-    //std::cerr << "MainWindow::startServer()" << std::endl;
-
     AppConfig::instance().setServerPID( 0 );
     AppConfig::instance().setKillServer( true );
 
+    std::string server_command;
+    if ( M_server_command.isEmpty() )
+    {
+        server_command = AppConfig::instance().serverPath();
+    }
+    else
+    {
+        server_command = M_server_command.ascii();
+        M_server_command.setLength( 0 );
+    }
+
 #if 1
-    std::string command = AppConfig::instance().serverPath();
     //command += " > /dev/null 2>&1 &";
-    command += " &";
-    std::system( command.c_str() );
+    server_command += " &";
+    std::system( server_command.c_str() );
 #else
-    // qt4
-    //QString command( AppConfig::instance().serverPath().c_str() );
-    //QProcess::startDetached( command );
+    QProcess * process = new QProcess( server_command, this );
+    process->start();
 #endif
-    if ( ! M_cursor_override )
+    if ( ! QApplication::overrideCursor() )
     {
         QApplication::setOverrideCursor( QCursor( Qt::WaitCursor ) );
-        M_cursor_override = true;
     }
 
     QTimer::singleShot( 1000,
@@ -1542,24 +1544,102 @@ MainWindow::startServer()
 void
 MainWindow::restartServer()
 {
-    //std::cerr << "MainWindow::restartServer()" << std::endl;
+    restartServer( AppConfig::instance().serverPath() );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+MainWindow::restartServer( const QString & command )
+{
+    static bool s_last_auto_start = false;
+
+    M_server_command = command;
+
+    bool auto_start = false;
+    if ( command.find( "server::team_l_start" ) != -1 )
+    {
+        auto_start = true;
+    }
+
     if ( M_monitor_client )
     {
         killServer();
 
-        if ( ! M_cursor_override )
+        if ( ! QApplication::overrideCursor() )
         {
             QApplication::setOverrideCursor( QCursor( Qt::WaitCursor ) );
-            M_cursor_override = true;
         }
 
-        QTimer::singleShot( 1000,
+        int timer_msec = 1000;
+        if ( s_last_auto_start )
+        {
+            timer_msec = 3000;
+        }
+
+        QTimer::singleShot( timer_msec,
                             this, SLOT( startServer() ) );
     }
     else
     {
         startServer();
     }
+
+    s_last_auto_start = auto_start;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+MainWindow::showLauncherDialog()
+{
+    if ( M_launcher_dialog )
+    {
+        if ( M_launcher_dialog->isVisible() )
+        {
+            M_launcher_dialog->hide();
+        }
+        else
+        {
+            M_launcher_dialog->show();
+        }
+    }
+    else
+    {
+        M_launcher_dialog = new LauncherDialog( this );
+        M_launcher_dialog->show();
+
+        //QSize size = M_launcher_dialog->size();
+        //M_launcher_dialog->setMinimumSize( size );
+        //M_launcher_dialog->setMaximumSize( size );
+        QSize size = M_launcher_dialog->size();
+        M_launcher_dialog->setMinimumSize( size );
+        M_launcher_dialog->setMaximumSize( 1024, size.height() );
+
+        connect( M_launcher_dialog, SIGNAL( launchServer( const QString & ) ),
+                 this, SLOT( restartServer( const QString & ) ) );
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+MainWindow::toggleMenuBar()
+{
+    if ( this->menuBar()->isVisible() )
+    {
+        this->menuBar()->hide();
+    }
+    else
+    {
+        this->menuBar()->show();
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -1803,11 +1883,7 @@ MainWindow::startDebugServer()
         return;
     }
 
-    //M_start_debug_server_act->setEnabled( false );
-    M_start_debug_server_act->setOn( true );
-    //M_stop_debug_server_act->setEnabled( true );
-
-    M_debug_server_running = true;
+    M_toggle_debug_server_mode_act->setOn( true );
 }
 
 /*-------------------------------------------------------------------*/
@@ -1824,13 +1900,6 @@ MainWindow::stopDebugServer()
         //std::cerr << "Stop Debug Server" << std::endl;
         M_debug_server.reset();
     }
-
-    //M_start_debug_server_act->setEnabled( M_monitor_client
-    //                                      ? true
-    //                                      : false );
-    //M_stop_debug_server_act->setEnabled( false );
-
-    M_debug_server_running = false;
 }
 
 /*-------------------------------------------------------------------*/
@@ -1870,7 +1939,7 @@ MainWindow::about()
                "soccerwindow2 Development Site:\n"
                "  http://rctools.sourceforge.jp/\n"
                "Author:\n"
-               "  Hidehisa Akiyama <akky@users.sourceforge.jp>" );
+               "  Hidehisa AKIYAMA <akky@users.sourceforge.jp>" );
 
     QMessageBox::about( this,
                         tr( "About soccerwindow2" ),
@@ -1988,8 +2057,8 @@ MainWindow::updatePositionLabel( const QPoint & point )
          && statusBar()->isVisible()
          )
     {
-        double x = M_main_data.viewConfig().getFieldX( point.x() );
-        double y = M_main_data.viewConfig().getFieldY( point.y() );
+        double x = M_main_data.viewConfig().fieldX( point.x() );
+        double y = M_main_data.viewConfig().fieldY( point.y() );
 
         char buf[32];
         std::snprintf( buf, 32,
@@ -2031,8 +2100,8 @@ MainWindow::dropBall( const QPoint & point )
     if ( M_monitor_client
          && M_monitor_client->isConnected() )
     {
-        double x = M_main_data.viewConfig().getFieldX( point.x() );
-        double y = M_main_data.viewConfig().getFieldY( point.y() );
+        double x = M_main_data.viewConfig().fieldX( point.x() );
+        double y = M_main_data.viewConfig().fieldY( point.y() );
 
         std::cerr << "drop ball to ("
                   << x << ", " << y << ")"
@@ -2051,8 +2120,8 @@ MainWindow::freeKickLeft( const QPoint & point )
     if ( M_monitor_client
          && M_monitor_client->isConnected() )
     {
-        double x = M_main_data.viewConfig().getFieldX( point.x() );
-        double y = M_main_data.viewConfig().getFieldY( point.y() );
+        double x = M_main_data.viewConfig().fieldX( point.x() );
+        double y = M_main_data.viewConfig().fieldY( point.y() );
 
         std::cerr << "free kick left at ("
                   << x << ", " << y << ")"
@@ -2071,8 +2140,8 @@ MainWindow::freeKickRight( const QPoint & point )
     if ( M_monitor_client
          && M_monitor_client->isConnected() )
     {
-        double x = M_main_data.viewConfig().getFieldX( point.x() );
-        double y = M_main_data.viewConfig().getFieldY( point.y() );
+        double x = M_main_data.viewConfig().fieldX( point.x() );
+        double y = M_main_data.viewConfig().fieldY( point.y() );
 
         std::cerr << "free kick right at ("
                   << x << ", " << y << ")"
