@@ -58,8 +58,10 @@ PlayerPainter::Param::Param( const Player & player,
                              const Ball & ball,
                              const ViewConfig & view_conf,
                              const rcsc::PlayerType & ptype )
-    : x_( view_conf.getScreenX( player.x() ) )
-    , y_( view_conf.getScreenY( player.y() ) )
+    : x_( view_conf.screenX( player.x() * view_conf.reverseValue() ) )
+    , y_( view_conf.screenY( player.y() * view_conf.reverseValue() ) )
+    , body_( player.body() + ( view_conf.reverseSide() ? 180.0 : 0.0 ) )
+    , head_( player.head() + ( view_conf.reverseSide() ? 180.0 : 0.0 ) )
     , body_radius_( view_conf.scale( ptype.playerSize() ) )
     , kick_radius_( view_conf.scale( ptype.kickableArea() ) )
     , have_full_effort_( player.hasFullEffort( ptype.effortMax() ) )
@@ -107,41 +109,65 @@ PlayerPainter::draw( QPainter & painter )
 
     const Ball & ball = view->ball();
 
-    const std::vector< Player >::const_iterator it_end = view->players().end();
-    for ( std::vector< Player >::const_iterator it = view->players().begin();
-          it != it_end;
-          ++it )
+    if ( M_main_data.viewConfig().playerReverseDraw() )
     {
-        const Param param( *it,
-                           ball,
-                           M_main_data.viewConfig(),
-                           M_main_data.viewHolder().playerType( it->type() ) );
-
-        drawBody( painter, param );
-        drawShadow( painter, param );
-        drawEdge( painter, param );
-
-        if ( M_main_data.viewConfig().isSelectedPlayer( it->side(), it->unum() )
-             && M_main_data.viewConfig().playerFutureCycle() > 0
-             && it->hasDelta() )
+        const std::vector< Player >::const_reverse_iterator end = view->players().rend();
+        for ( std::vector< Player >::const_reverse_iterator it = view->players().rbegin();
+              it != end;
+              ++it )
         {
-            drawFuture( painter, param );
+            drawAll( painter, *it, ball );
         }
-
-        if ( it->hasView()
-             && M_main_data.viewConfig().isShownViewCone() )
+    }
+    else
+    {
+        const std::vector< Player >::const_iterator end = view->players().end();
+        for ( std::vector< Player >::const_iterator it = view->players().begin();
+              it != end;
+              ++it )
         {
-            drawViewCone( painter, param );
+            drawAll( painter, *it, ball );
         }
+    }
+}
 
-        if ( M_main_data.viewConfig().isShownControlArea() )
-        {
-            drawControlArea( painter, param );
-        }
+/*-------------------------------------------------------------------*/
+/*
 
-        drawText( painter, param );
+*/
+void
+PlayerPainter::drawAll(  QPainter & painter,
+                         const Player & player,
+                         const Ball & ball ) const
+{
+    const Param param( player,
+                       ball,
+                       M_main_data.viewConfig(),
+                       M_main_data.viewHolder().playerType( player.type() ) );
+
+    drawBody( painter, param );
+    drawShadow( painter, param );
+    drawEdge( painter, param );
+
+    if ( M_main_data.viewConfig().isSelectedPlayer( player.side(), player.unum() )
+         && M_main_data.viewConfig().playerFutureCycle() > 0
+         && player.hasDelta() )
+    {
+        drawFuture( painter, param );
     }
 
+    if ( player.hasView()
+         && M_main_data.viewConfig().isShownViewCone() )
+    {
+        drawViewCone( painter, param );
+    }
+
+    if ( M_main_data.viewConfig().isShownControlArea() )
+    {
+        drawControlArea( painter, param );
+    }
+
+    drawText( painter, param );
 }
 
 /*-------------------------------------------------------------------*/
@@ -157,7 +183,13 @@ PlayerPainter::drawBody( QPainter & painter,
     // decide base color
     painter.setPen( dconf.playerPen() );
 
-    switch ( param.player_.side() ) {
+    rcsc::SideID side = param.player_.side();
+    if ( M_main_data.viewConfig().reverseSide() )
+    {
+        side = static_cast< rcsc::SideID >( -1 * side );
+    }
+
+    switch ( side ) {
     case rcsc::LEFT:
         if ( param.player_.isGoalie() )
         {
@@ -232,6 +264,7 @@ PlayerPainter::drawBody( QPainter & painter,
                          param.y_ - param.draw_radius_ ,
                          param.draw_radius_ * 2,
                          param.draw_radius_ * 2 );
+
 }
 
 /*-------------------------------------------------------------------*/
@@ -248,7 +281,7 @@ PlayerPainter::drawShadow( QPainter & painter,
     int shadow_radius = static_cast< int >( param.draw_radius_ * 0.9 );
     // set angle
     int shadow_start_dir
-        = static_cast< int >( rint( ( - param.player_.body() + 90.0 ) * 16 ) );
+        = static_cast< int >( rint( ( - param.body_ + 90.0 ) * 16 ) );
     //double shadow_end_dir = shadow_start_dir + 180.0;
 
     // decide shadow color
@@ -301,7 +334,7 @@ PlayerPainter::drawShadow( QPainter & painter,
 */
 void
 PlayerPainter::drawEdge( QPainter & painter,
-                         const PlayerPainter::Param & param )
+                         const PlayerPainter::Param & param ) const
 {
     const DrawConfig & dconf = DrawConfig::instance();
 
@@ -374,11 +407,16 @@ PlayerPainter::drawFuture( QPainter & painter,
     // draw future state
     rcsc::Vector2D ppos( param.player_.x(), param.player_.y() );
     rcsc::Vector2D pvel( param.player_.deltaX(), param.player_.deltaY() );
+    if ( M_main_data.viewConfig().reverseSide() )
+    {
+        ppos *= -1.0;
+        pvel *= -1.0;
+    }
 
     const int last = M_main_data.viewConfig().playerFutureCycle();
 
-    QPoint first_point( M_main_data.viewConfig().getScreenX( ppos.x ),
-                        M_main_data.viewConfig().getScreenY( ppos.y ) ) ;
+    QPoint first_point( M_main_data.viewConfig().screenX( ppos.x ),
+                        M_main_data.viewConfig().screenY( ppos.y ) ) ;
     QPoint last_point = first_point;
 
     // draw kickable area edge
@@ -398,8 +436,8 @@ PlayerPainter::drawFuture( QPainter & painter,
         ppos += pvel;
         pvel *= param.player_type_.playerDecay();
 
-        QPoint pt( M_main_data.viewConfig().getScreenX( ppos.x ),
-                   M_main_data.viewConfig().getScreenY( ppos.y ) );
+        QPoint pt( M_main_data.viewConfig().screenX( ppos.x ),
+                   M_main_data.viewConfig().screenY( ppos.y ) );
         if ( std::abs( last_point.x() - pt.x() ) < 1
              && std::abs( last_point.y() - pt.y() ) < 1 )
         {
@@ -439,9 +477,9 @@ PlayerPainter::drawViewCone( QPainter & painter,
     const double visible_dist = rcsc::ServerParam::i().visibleDistance();
     const int visible_radius = vconf.scale( visible_dist );
 
-    const double view_start_angle = -param.player_.head() - view_width * 0.5;
-    const double view_start_angle_real = ( param.player_.head() - view_width * 0.5 ) * rcsc::AngleDeg::DEG2RAD;
-    const double view_end_angle_real = ( param.player_.head() + view_width * 0.5 ) * rcsc::AngleDeg::DEG2RAD;
+    const double view_start_angle = -param.head_ - view_width * 0.5;
+    const double view_start_angle_real = ( param.head_ - view_width * 0.5 ) * rcsc::AngleDeg::DEG2RAD;
+    const double view_end_angle_real = ( param.head_ + view_width * 0.5 ) * rcsc::AngleDeg::DEG2RAD;
 
     int view_start_angle_int
         = static_cast< int >( rint( view_start_angle * 16 ) );
@@ -455,7 +493,9 @@ PlayerPainter::drawViewCone( QPainter & painter,
         const int TEAM_FAR = vconf.scale( 40.0 );
         const int TEAM_TOOFAR = vconf.scale( 60.0 );
 
+        //painter.setRasterOp( Qt::OrROP );
         painter.setPen( dconf.viewAreaPen() );
+        //painter.setBrush( dconf.fieldDarkBrush() );
         //painter.setBrush( dconf.transparentBrush() );
 
         painter.drawArc( param.x_ - UNUM_FAR, // left x
@@ -472,6 +512,7 @@ PlayerPainter::drawViewCone( QPainter & painter,
                          span_angle );
         // pie, no an arc
         painter.drawArc( param.x_ - TEAM_TOOFAR, // left x
+        //painter.drawPie( param.x_ - TEAM_TOOFAR, // left x
                          param.y_ - TEAM_TOOFAR, // toop y
                          TEAM_TOOFAR * 2, // width
                          TEAM_TOOFAR * 2, // height
@@ -499,6 +540,8 @@ PlayerPainter::drawViewCone( QPainter & painter,
             + vconf.scale( 60.0 * std::sin( view_end_angle_real ) );
         painter.drawLine( lx, ly, param.x_, param.y_ );
         painter.drawLine( rx, ry, param.x_, param.y_ );
+
+        //painter.setRasterOp( Qt::CopyROP );
     }
     else
     {
@@ -544,8 +587,14 @@ PlayerPainter::drawControlArea( QPainter & painter,
                          param.player_.y() );
     rcsc::Vector2D bpos( param.ball_.x(),
                          param.ball_.y() );
+    if ( vconf.reverseSide() )
+    {
+        ppos *= -1.0;
+        bpos *= -1.0;
+    }
+
     rcsc::Vector2D player_to_ball = bpos - ppos;
-    player_to_ball.rotate( - param.player_.body() );
+    player_to_ball.rotate( - param.body_ );
 
     // draw tackle area & probability
     double tackle_dist = ( player_to_ball.x > 0.0
@@ -557,7 +606,7 @@ PlayerPainter::drawControlArea( QPainter & painter,
                                        rcsc::ServerParam::i().tackleExponent() ) );
     if ( tackle_prob < 1.0 )
     {
-        rcsc::AngleDeg body_angle = param.player_.body();
+        rcsc::AngleDeg body_angle = param.body_;
         rcsc::AngleDeg body_angle_side = body_angle + 90.0;
         double body_x = body_angle.cos();
         double body_y = body_angle.sin();
@@ -569,14 +618,14 @@ PlayerPainter::drawControlArea( QPainter & painter,
         double right_y = rcsc::ServerParam::i().tackleWidth() * body_angle_side.sin();
 
         QPointArray pts( 4 );
-        pts[0].setX( vconf.getScreenX( ppos.x + forward_x + right_x ) );
-        pts[0].setY( vconf.getScreenY( ppos.y + forward_y + right_y ) );
-        pts[1].setX( vconf.getScreenX( ppos.x + forward_x - right_x ) );
-        pts[1].setY( vconf.getScreenY( ppos.y + forward_y - right_y ) );
-        pts[2].setX( vconf.getScreenX( ppos.x + back_x - right_x ) );
-        pts[2].setY( vconf.getScreenY( ppos.y + back_y - right_y ) );
-        pts[3].setX( vconf.getScreenX( ppos.x + back_x + right_x ) );
-        pts[3].setY( vconf.getScreenY( ppos.y + back_y + right_y ) );
+        pts[0].setX( vconf.screenX( ppos.x + forward_x + right_x ) );
+        pts[0].setY( vconf.screenY( ppos.y + forward_y + right_y ) );
+        pts[1].setX( vconf.screenX( ppos.x + forward_x - right_x ) );
+        pts[1].setY( vconf.screenY( ppos.y + forward_y - right_y ) );
+        pts[2].setX( vconf.screenX( ppos.x + back_x - right_x ) );
+        pts[2].setY( vconf.screenY( ppos.y + back_y - right_y ) );
+        pts[3].setX( vconf.screenX( ppos.x + back_x + right_x ) );
+        pts[3].setY( vconf.screenY( ppos.y + back_y + right_y ) );
 
         painter.setPen( dconf.tackleAreaPen() );
         painter.setBrush( dconf.transparentBrush() );
@@ -613,6 +662,8 @@ PlayerPainter::drawText( QPainter & painter,
 
     const int text_radius = std::min( 40, param.draw_radius_ );
 
+    painter.setFont( dconf.playerFont() );
+
     if ( vconf.isShownPlayerNumber()
          && vconf.isShownHeteroNumber() )
     {
@@ -670,7 +721,6 @@ PlayerPainter::drawText( QPainter & painter,
                            static_cast< int >( rint( param.player_.stamina() ) ) );
 
             painter.setPen( dconf.playerStaminaFontPen() );
-            painter.setFont( dconf.playerFont() );
             painter.drawText( param.x_ - text_radius,
                               param.y_ - text_radius - 3,
                               QString::fromAscii( buf ) );
