@@ -91,6 +91,9 @@ ViewConfigDialog::createWidgets()
     // canvas size
     layout->addWidget( createCanvasSizeControls(),
                        0, Qt::AlignLeft );
+    // reverse mode
+    layout->addWidget( createReverseControls(),
+                       0, Qt::AlignLeft );
     // detail info options
     layout->addWidget( createPlayersDetailControls(),
                        0, Qt::AlignLeft );
@@ -246,6 +249,30 @@ ViewConfigDialog::createCanvasSizeControls()
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+QWidget *
+ViewConfigDialog::createReverseControls()
+{
+    QHGroupBox * group_box = new QHGroupBox( tr( "Reverse" ), this );
+    group_box->setInsideMargin( 5 );
+    group_box->setInsideSpacing( 2 );
+
+    M_reverse_side_cb = new QCheckBox( tr( "Reverse Side" ), group_box );
+    M_reverse_side_cb->setChecked( M_view_config.reverseSide() );
+    connect( M_reverse_side_cb, SIGNAL( toggled( bool ) ),
+             this, SLOT( clickReverseSide( bool ) ) );
+
+    M_player_reverse_draw_cb = new QCheckBox( tr( "Reverse Player Draw Order" ), group_box );
+    M_player_reverse_draw_cb->setChecked( M_view_config.playerReverseDraw() );
+    connect( M_player_reverse_draw_cb, SIGNAL( toggled( bool ) ),
+             this, SLOT( clickPlayerReverseDraw( bool ) ) );
+
+    return group_box;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 QWidget *
 ViewConfigDialog::createPlayersDetailControls()
@@ -1057,6 +1084,60 @@ ViewConfigDialog::applyCanvasSize()
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+ViewConfigDialog::clickReverseSide( bool checked )
+{
+    if ( M_view_config.reverseSide() != checked )
+    {
+        M_view_config.toggleReverseSide();
+        emit configured();
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+ViewConfigDialog::toggleReverseSide()
+{
+    M_view_config.toggleReverseSide();
+    M_reverse_side_cb->setChecked( M_view_config.reverseSide() );
+
+    emit configured();
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+ViewConfigDialog::clickPlayerReverseDraw( bool checked )
+{
+    if ( M_view_config.playerReverseDraw() != checked )
+    {
+        M_view_config.togglePlayerReverseDraw();
+        emit configured();
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+ViewConfigDialog::togglePlayerReverseDraw()
+{
+    M_view_config.togglePlayerReverseDraw();
+    M_player_reverse_draw_cb->setChecked( M_view_config.playerReverseDraw() );
+
+    emit configured();
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 ViewConfigDialog::clickShowPlayerNumber( bool checked )
@@ -1596,9 +1677,13 @@ ViewConfigDialog::toggleSelectAutoAll()
 void
 ViewConfigDialog::clickSelectAutoLeft()
 {
-    if ( M_view_config.playerSelectType() != ViewConfig::SELECT_AUTO_LEFT )
+    ViewConfig::PlayerSelectType type = ( M_view_config.reverseSide()
+                                          ? ViewConfig::SELECT_AUTO_RIGHT
+                                          : ViewConfig::SELECT_AUTO_LEFT );
+
+    if ( M_view_config.playerSelectType() != type )
     {
-        M_view_config.setPlayerSelectType( ViewConfig::SELECT_AUTO_LEFT );
+        M_view_config.setPlayerSelectType( type );
         emit configured();
     }
 }
@@ -1610,13 +1695,17 @@ ViewConfigDialog::clickSelectAutoLeft()
 void
 ViewConfigDialog::toggleSelectAutoLeft()
 {
-    if ( M_view_config.playerSelectType() == ViewConfig::SELECT_AUTO_LEFT )
+    ViewConfig::PlayerSelectType type = ( M_view_config.reverseSide()
+                                          ? ViewConfig::SELECT_AUTO_RIGHT
+                                          : ViewConfig::SELECT_AUTO_LEFT );
+
+    if ( M_view_config.playerSelectType() == type )
     {
         setUnselect();
     }
     else
     {
-        M_view_config.setPlayerSelectType( ViewConfig::SELECT_AUTO_LEFT );
+        M_view_config.setPlayerSelectType( type );
         M_select_left_rb->setChecked( true );
 
         emit configured();
@@ -1630,9 +1719,13 @@ ViewConfigDialog::toggleSelectAutoLeft()
 void
 ViewConfigDialog::clickSelectAutoRight()
 {
-    if ( M_view_config.playerSelectType() != ViewConfig::SELECT_AUTO_RIGHT )
+    ViewConfig::PlayerSelectType type = ( M_view_config.reverseSide()
+                                          ? ViewConfig::SELECT_AUTO_LEFT
+                                          : ViewConfig::SELECT_AUTO_RIGHT );
+
+    if ( M_view_config.playerSelectType() != type )
     {
-        M_view_config.setPlayerSelectType( ViewConfig::SELECT_AUTO_RIGHT );
+        M_view_config.setPlayerSelectType( type );
         emit configured();
     }
 }
@@ -1644,13 +1737,17 @@ ViewConfigDialog::clickSelectAutoRight()
 void
 ViewConfigDialog::toggleSelectAutoRight()
 {
-    if ( M_view_config.playerSelectType() == ViewConfig::SELECT_AUTO_RIGHT )
+    ViewConfig::PlayerSelectType type = ( M_view_config.reverseSide()
+                                          ? ViewConfig::SELECT_AUTO_LEFT
+                                          : ViewConfig::SELECT_AUTO_RIGHT );
+
+    if ( M_view_config.playerSelectType() == type )
     {
         setUnselect();
     }
     else
     {
-        M_view_config.setPlayerSelectType( ViewConfig::SELECT_AUTO_RIGHT );
+        M_view_config.setPlayerSelectType( type );
         M_select_right_rb->setChecked( true );
 
         emit configured();
@@ -1721,6 +1818,18 @@ ViewConfigDialog::selectPlayer( int number )
         return;
     }
 
+    if ( M_view_config.reverseSide() )
+    {
+        if ( number <= 11 )
+        {
+            number += 11;
+        }
+        else
+        {
+            number -= 11;
+        }
+    }
+
     M_view_config.setPlayerSelectType( ViewConfig::SELECT_FIX );
     if ( number <= 11 )
     {
